<?php
namespace App\Controllers;

use CodeIgniter\Controller;
use App\Models\JoinMateriasModel;
use App\Models\RelacionMateriasUsuariosModel;
use App\Models\MateriaModel;
use App\Models\Allmymateriasmaestros;
use App\Models\EventsModel;

class Dashboard extends Controller
{
    public function index()
    {
        if (!session()->is_logged) {
            return view('login');
        }
     // Puedes pasar datos adicionales a la vista si es necesario
     $eventsModel = new EventsModel();
     $data['events'] = $eventsModel->getAllEvents();
 
     return view('dashboard', $data);
    }
   public function getMateriasMaestro()
    {
        $model = new RelacionMateriasUsuariosModel();
        $userId = session('PK_User');

        $materias = $model->groupStart()
                          ->where('FK_User', $userId)
                          ->orWhere('CreatedBy', $userId)
                          ->groupEnd()
                          ->findAll();

        return $this->response->setJSON($materias);
    }
    public function getMaterias()
    {
        $model = new RelacionMateriasUsuariosModel();
        $materiaModel = new MateriaModel();
        $userId = session('PK_User');
        
        // Obtener todas las materias del usuario
        $materias = $model->where('FK_User', $userId)
                          ->where('Status', 1)
                          ->findAll();
    
        // Añadir el campo 'Meet' a cada materia
        foreach ($materias as &$materia) {
            $materiaDetails = $materiaModel->find($materia['FK_Materia']);
            if ($materiaDetails) {
                $materia['Meet'] = $materiaDetails['Meet'];
            } else {
                $materia['Meet'] = null; // Si no se encuentra el campo Meet
            }
        }
    
        return $this->response->setJSON($materias);
    }
    
    public function getMateriasMaestroEspecial()
    {
        $userId = session('PK_User');
        $userType = session('FK_Rol');
    
        if ($userId && $userType) {
            $model = new Allmymateriasmaestros();
            $materiaModel = new MateriaModel();
            
            $materias = $model->where('FK_User', $userId)
                              ->where('FK_Rol', $userType)
                              ->where('Status', 1)
                              ->findAll();
    
            foreach ($materias as &$materia) {
                $materiaDetails = $materiaModel->find($materia['FK_Materia']);
                if ($materiaDetails) {
                    $materia['Meet'] = $materiaDetails['Meet'];
                } else {
                    $materia['Meet'] = null; // Si no se encuentra el campo Meet
                }
            }
                                  
            return $this->response->setJSON($materias);
        } else {
            return $this->response->setJSON(['error' => 'User ID or Role ID not authorized']);
        }
    }
    
    

    public function joinCourse()
    {
        $userId = session('PK_User');
        $request = $this->request->getJSON();
        $codeClass = $request->courseCode;
    
        log_message('debug', 'Datos recibidos: UserID: ' . $userId . ', CodeClass: ' . $codeClass);
    
        $materiasModel = new MateriaModel();
        $materia = $materiasModel->where('CodeClass', $codeClass)->first();
    
        if ($materia) {
            log_message('debug', 'Materia encontrada: ' . json_encode($materia));
    
            $joinModel = new JoinMateriasModel();
            $data = [
                'FK_User' => $userId,
                'FK_Materia' => $materia['PK_Materia']
            ];
    
            $existingEntry = $joinModel->where('FK_User', $userId)->where('FK_Materia', $materia['PK_Materia'])->first();
            if ($existingEntry) {
                log_message('info', 'El usuario ya está unido a la materia: ' . $materia['PK_Materia']);
                return $this->response->setJSON(['status' => 'error', 'message' => 'Ya estás unido a esta materia.']);
            }
    
            try {
                log_message('debug', 'Datos a insertar: ' . json_encode($data));
    
                if (!$joinModel->validate($data)) {
                    $errors = $joinModel->errors();
                    log_message('error', 'Validación fallida: ' . json_encode($errors) . ' para el usuario: ' . $userId);
                    return $this->response->setJSON(['status' => 'error', 'message' => 'Validación fallida', 'errors' => $errors]);
                }
    
                $insertResult = $joinModel->insert($data, false); 
                log_message('debug', 'Resultado de la inserción: ' . var_export($insertResult, true));
    
                $dbError = $joinModel->db->error();
                if ($dbError['code'] != 0) {
                    log_message('error', 'Error de base de datos: ' . var_export($dbError, true));
                    return $this->response->setJSON(['status' => 'error', 'message' => 'Error de base de datos.', 'errors' => $dbError]);
                }
    
                if ($insertResult) {
                    $affectedRows = $joinModel->db->affectedRows();
                    log_message('debug', 'Filas afectadas: ' . $affectedRows);
    
                    if ($affectedRows > 0) {
                        log_message('info', 'Materia unida correctamente para el usuario: ' . $userId);
                        return $this->response->setJSON(['status' => 'success', 'message' => 'Te has unido a la materia correctamente.']);
                    } else {
                        log_message('error', 'Error al unirse a la materia: Ninguna fila afectada para el usuario: ' . $userId);
                        return $this->response->setJSON(['status' => 'error', 'message' => 'Error al unirse a la materia. Ninguna fila afectada.']);
                    }
                } else {
                    $error = $joinModel->errors();
                    log_message('error', 'Error al unirse a la materia: ' . json_encode($error) . ' para el usuario: ' . $userId);
                    return $this->response->setJSON(['status' => 'error', 'message' => 'Error al unirse a la materia.', 'errors' => $error]);
                }
            } catch (\Exception $e) {
                log_message('error', 'Excepción al unirse a la materia: ' . $e->getMessage() . ' para el usuario: ' . $userId);
                return $this->response->setJSON(['status' => 'error', 'message' => 'Excepción al unirse a la materia.', 'exception' => $e->getMessage()]);
            }
        } else {
            log_message('info', 'Materia no encontrada para el código: ' . $codeClass . ' por el usuario: ' . $userId);
            return $this->response->setJSON(['status' => 'error', 'message' => 'No se encontró la materia con el código proporcionado.']);
        }
    }
    
    
}
