<?php
namespace App\Controllers;

use CodeIgniter\Controller;
use App\Models\MateriasModel;

class Library extends Controller
{
    public function index()
    {
        // return view('dashboard');
        if(!session()->is_logged){
            return view('login');
        }
        $directory = FCPATH . '../public/uploads/library';

        // Obtener lista de archivos
        $files = [];
        if (is_dir($directory)) {
            if ($handle = opendir($directory)) {
                while (($file = readdir($handle)) !== false) {
                    if ($file != '.' && $file != '..') {
                        $files[] = $file;
                    }
                }
                closedir($handle);
            }
        }

        $links = [];
        $linksFile = $directory . '/links.txt';
        if (file_exists($linksFile)) {
            $links = file($linksFile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
        }

        $data = array_merge($files, $links);
        
        return view('library', ['items' => $data]);
    }

    public function upload() {
        helper(['form', 'url']);
        
        // Definir los tipos de archivo permitidos y el tamaño máximo (80 MB)
        $allowedFileTypes = [
            'application/pdf', // PDF
            'application/vnd.openxmlformats-officedocument.wordprocessingml.document', // DOCX
            'application/vnd.openxmlformats-officedocument.presentationml.presentation', // PPTX
            'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' // XLSX
        ];
        $maxFileSize = 80 * 1024 * 1024; // 80MB
    
        // Obtener el archivo y el enlace desde el request
        $file = $this->request->getFile('file');
        $link = $this->request->getPost('link');
    
        // Validar archivo
        if ($file && $file->isValid() && !$file->hasMoved()) {
            $fileType = $file->getMimeType();
            $fileSize = $file->getSize();
    
            // Verificar tipo de archivo permitido
            if (!in_array($fileType, $allowedFileTypes)) {
                return redirect()->back()->with('error', 'Formato de archivo no permitido. Solo se permiten PDF, DOCX, PPTX y XLSX.');
            }
    
            // Verificar tamaño de archivo
            if ($fileSize > $maxFileSize) {
                return redirect()->back()->with('error', 'El archivo excede el tamaño máximo permitido de 80 MB.');
            }
    
            // Guardar el archivo en la ruta especificada
            $file->move(WRITEPATH . '../public/uploads/library');
            $fileName = $file->getName();
    
            // Redireccionar con mensaje de éxito
            return redirect()->back()->with('success', 'Archivo subido correctamente');
        } elseif ($link) {
            // Guardar el enlace en un archivo de texto o simplemente usarlo en el servidor
            $filePath = WRITEPATH . '../public/uploads/library/links.txt';
            file_put_contents($filePath, $link . PHP_EOL, FILE_APPEND);
    
            // Redireccionar con mensaje de éxito
            return redirect()->back()->with('success', 'Enlace de libro subido correctamente');
        } else {
            // Manejar el caso en que no se ha subido un archivo ni ingresado un enlace
            return redirect()->back()->with('error', 'Por favor suba un archivo o ingrese un enlace');
        }
    }
    
    
      
      public function delete($item)
      {
          // Verificar si el ítem es una URL o un archivo
          if (filter_var($item, FILTER_VALIDATE_URL)) {
              // Aquí podrías agregar lógica para manejar enlaces si es necesario
              // Ejemplo: Registrar la eliminación en un archivo de registro o base de datos
              // No se puede eliminar enlaces directamente desde el servidor
              return $this->response->setJSON(['status' => 'error', 'message' => 'No se pueden eliminar enlaces directamente.']);
          } else {
              // Eliminar el archivo del servidor
              $filePath = WRITEPATH . '../public/uploads/library/' . $item;
              if (file_exists($filePath)) {
                  unlink($filePath);
                  return $this->response->setJSON(['status' => 'success', 'message' => 'Archivo eliminado con éxito.']);
              } else {
                  return $this->response->setJSON(['status' => 'error', 'message' => 'Archivo no encontrado.']);
              }
          }
      }
    
}

