<?php namespace App\Controllers;

use CodeIgniter\Controller;
use App\Models\MateriasModel;
use App\Models\TareasModel;
use App\Models\TareasInfoModel;
use App\Models\TareasUsuarioModel;
use App\Models\UserModel;
use App\Models\GruposAlumnosModel;
use App\Models\MateriaModel;
use App\Models\UserMateriasModel;
use App\Models\MateriasMaestrosModel;
use App\Models\RelacionMateriasUsuariosModel;
use App\Models\Allmymateriasmaestros;
    
class Materia extends Controller
{
    public function __construct()
    {
        if (!session()->get('is_logged')) {
            header('Location: ' . base_url());
            exit();
        }
    }
    public function getMaterias()
    {
        // Inicializa los modelos
        $relacionMateriasModel = new RelacionMateriasUsuariosModel();
        $allMateriasMaestrosModel = new Allmymateriasmaestros();
        $materiaModel = new MateriaModel();

        // Obtén el ID y el tipo de usuario de la sesión
        $userId = session('PK_User');
        $userType = session('FK_Rol');

        // Verifica si el usuario está autenticado
        if (!$userId) {
            return $this->response->setJSON(['error' => 'Usuario no autenticado']);
        }

        // Dependiendo del tipo de usuario, trae las materias correspondientes
        if ($userType == 3) {
            // Si es maestro, usa el modelo de relaciones de maestros
            $materias = $allMateriasMaestrosModel->where('FK_User', $userId)->findAll();
        } elseif ($userType == 4) {
            // Si es alumno, usa el modelo de relaciones de alumnos
            $materias = $relacionMateriasModel->getMateriasByUser($userId);
        } else {
            // Si es cualquier otro rol (por ejemplo, coordinación académica), usa el modelo de materias
            $materias = $materiaModel->getMateriasByUser($userId, $userType);
        }

        // Devolver las materias en formato JSON
        return $this->response->setJSON($materias);
    }

    public function getCalificaciones()
    {
        $session = session();
        $userId = $session->get('PK_User');
        $materiaId = $this->request->getPost('materiaId');

        $tareasModel = new TareasInfoModel();
        $calificaciones = $tareasModel->where('FK_User', $userId)
                                      ->where('FK_Materia', $materiaId)
                                      ->findAll();

        return $this->response->setJSON($calificaciones);
    }

    public function setSessionMateria()
    {
        $pkMateria = $this->request->getJSON()->pkMateria;
        session()->set('pkMateria', $pkMateria);
        return $this->response->setJSON(['status' => 'success']);
    }

    public function mostrar($id)
    {
        $materiasModel = new MateriasModel();
        $userMateriasModel = new UserMateriasModel(); 
        $materiasMaestrosModel = new MateriasMaestrosModel();
        $userId = session('PK_User'); 
        $userType = session('FK_Rol'); 
    
        // Obtener la materia según el ID
        $data['materia'] = $materiasModel->find($id);
        
        if ($data['materia'] === null) {
            return redirect()->to(base_url())->with('error', 'Materia no encontrada');
        }
    
        // Si el usuario no es de tipo Coordinador Académico (2), verificamos si está asignado
        if ($userType != 2) {
            $isAssigned = false;
            
            // Verificar si el rol es Maestro
            if ($userType == 3) {
                // El maestro debe estar asignado a la materia en `t_materias_maestros`
                $isAssigned = $materiasMaestrosModel->where('FK_User', $userId)
                                                    ->where('FK_Materia', $id)
                                                    ->first();
            } 
            // Verificar si el rol es Alumno
            elseif ($userType == 4) {
                // El alumno debe estar inscrito en la materia en `t_user_materias`
                $isAssigned = $userMateriasModel->where('FK_User', $userId)
                                                ->where('FK_Materia', $id)
                                                ->first();
            }
    
            // Si el usuario no está asignado, redirigirlo al dashboard con un mensaje de error
            if (!$isAssigned) {
                return redirect()->to(base_url('dashboard'))->with('error', 'No estás asignado a esta materia');
            }
        }
    
        // Determinar el tipo de usuario para mostrar en la vista
        $userTypeText = '';
        switch ($userType) {
            case 1:
                $userTypeText = 'Visitante';
                break;
            case 2:
                $userTypeText = 'Coordinación Académica';
                break;
            case 3:
                $userTypeText = 'Maestro';
                break;
            case 4:
                $userTypeText = 'Alumno';
                break;
            case 5:
                $userTypeText = 'Director';
                break;
        }
    
        // Agregar los datos del usuario y el hash de sesión para la vista
        $data['userType'] = $userType;
        $data['userTypeText'] = $userTypeText;
        $data['sessionHash'] = md5(session_id() . time());
    
        return view('materia', $data);
    }
    
    
    
    public function mostrarTareas($id)
    {
        $tareasModel = new TareasModel();
        $tareas = $tareasModel->where('FK_Materia', $id)->findAll();

        return $this->response->setJSON($tareas);
    }public function crearTarea()
    {
        $validation = \Config\Services::validation();
    
        $validation->setRules([
            'taskTitle' => 'required',
            'taskDescription' => 'required',
            'taskDueDate' => 'required|valid_date',
            'materiaId' => 'required',
            'estado' => 'required',
            'asignadoPor' => 'required',
            'groupId' => 'required'
        ]);
    
        if (!$validation->withRequest($this->request)->run()) {
            return $this->response->setJSON(['status' => 'error', 'errors' => $validation->getErrors()]);
        }
    
        $tareasModel = new TareasModel();
        $tareasUsuarioModel = new TareasUsuarioModel();
        $gruposAlumnosModel = new GruposAlumnosModel();
    
        $data = [
            'Nombre' => $this->request->getPost('taskTitle'),
            'Descripción' => $this->request->getPost('taskDescription'),
            'FechaCreación' => date('Y-m-d H:i:s'),
            'FechaEntrega' => $this->request->getPost('taskDueDate'),
            'Estado' => $this->request->getPost('estado'),
            'AsignadoPor' => $this->request->getPost('asignadoPor'),
            'FK_Materia' => $this->request->getPost('materiaId')
        ];
    
        if ($tareasModel->insert($data)) {
            $insertedTareaId = $tareasModel->getInsertID();
    
            $materiaId = $this->request->getPost('materiaId');
            $groupId = $this->request->getPost('groupId');
            $usuarios = $gruposAlumnosModel->where('PK_Group', $groupId)->findAll();
    
            foreach ($usuarios as $usuario) {
                $tareasUsuariosData = [
                    'FK_Tarea' => $insertedTareaId,
                    'FK_User' => $usuario['PK_User'],
                    'FK_Materia' => $materiaId,
                    'Calificacion' => 0,
                    'Estado' => 'Pendiente'
                ];
                $tareasUsuarioModel->insert($tareasUsuariosData);
            }
    
            return $this->response->setJSON(['status' => 'success']);
        } else {
            return $this->response->setJSON(['status' => 'error']);
        }
    }
    
    public function getGroups()
    {
        $gruposAlumnosModel = new GruposAlumnosModel();
        $groups = $gruposAlumnosModel->select('PK_Group, GroupName')->distinct()->findAll();
        
        return $this->response->setJSON($groups);
    }
    
    public function getCodeClass()
    {
        $materiaId = $this->request->getJSON()->materiaId;
        $materiasModel = new MateriasModel();
        
        $materia = $materiasModel->find($materiaId);
        
        if ($materia) {
            return $this->response->setJSON(['status' => 'success', 'codeClass' => $materia['CodeClass']]);
        } else {
            return $this->response->setJSON(['status' => 'error', 'message' => 'Materia no encontrada']);
        }
    }   

    public function getMeetClass()
    {
        $materiaId = $this->request->getJSON()->materiaId;
        $materiasModel = new MateriaModel();
        
        $materia = $materiasModel->find($materiaId);
        
        if ($materia) {
            return $this->response->setJSON(['status' => 'success', 'meet' => $materia['Meet']]);
        } else {
            return $this->response->setJSON(['status' => 'error', 'message' => 'Materia no encontrada']);
        }
    }
    
    
}
