<?php
namespace App\Controllers;

use App\Models\MaterialEducativoModel;

class MaterialEducativo extends BaseController
{
    public function __construct()
    {
        if (!session()->get('is_logged')) {
            header('Location: ' . base_url());
            exit();
        }
    }

    public function list($pkMateria)
    {
        $model = new MaterialEducativoModel();
        $fkUser = session('PK_User');
        $userType = session('FK_Rol');
        $limit = 5; 
        $offset = $this->request->getGet('page') ? ($this->request->getGet('page') - 1) * $limit : 0;

        log_message('debug', 'UserType: ' . $userType);
        log_message('debug', 'PK_Materia: ' . $pkMateria);
        log_message('debug', 'FK_User: ' . $fkUser);
        log_message('debug', 'Limit: ' . $limit);
        log_message('debug', 'Offset: ' . $offset);

        if ($userType == 3) { // Profesor
            $materials = $model->where('FK_Materia', $pkMateria)
                               ->where('FK_User', $fkUser)
                               ->findAll($limit, $offset);
            $totalMaterials = $model->where('FK_Materia', $pkMateria)
                                    ->where('FK_User', $fkUser)
                                    ->countAllResults();
        } else if ($userType == 4) { // Alumno
            $materials = $model->where('FK_Materia', $pkMateria)
                               ->findAll($limit, $offset);
            $totalMaterials = $model->where('FK_Materia', $pkMateria)
                                    ->countAllResults();
        } else {
            // Manejar otros tipos de usuario o error
            $materials = [];
            $totalMaterials = 0;
        }

        log_message('debug', 'Materials: ' . print_r($materials, true));
        log_message('debug', 'TotalMaterials: ' . $totalMaterials);

        $data = [
            'materials' => $materials,
            'pkMateria' => $pkMateria,
            'userType' => $userType,
            'currentPage' => $this->request->getGet('page') ? $this->request->getGet('page') : 1,
            'totalPages' => ceil($totalMaterials / $limit)
        ];

        return view('ver_material', $data);
    }

    public function store()
    {
        $model = new MaterialEducativoModel();
        $file = $this->request->getFile('Archivo');
        $pkMateria = session('pkMateria');
        $fkUser = session('PK_User');

        if ($file->isValid() && !$file->hasMoved()) {
            $newName = $file->getRandomName();
            $file->move(WRITEPATH . '../public/uploads/material', $newName);

            $data = [
                'NombreMaterial' => $this->request->getPost('NombreMaterial'),
                'Descripción' => $this->request->getPost('Descripción'),
                'Archivo' => $newName,
                'FK_Materia' => $pkMateria,
                'FK_User' => $fkUser
            ];

            if ($model->insert($data)) {
                return $this->response->setJSON(['success' => true]);
            } else {
                return $this->response->setJSON(['success' => false, 'error' => 'Failed to save to database.']);
            }
        }

        return $this->response->setJSON(['success' => false, 'error' => 'Invalid file upload.']);
    }

    public function setSessionMateria()
    {
        $request = \Config\Services::request();
        $pkMateria = $request->getJSON()->pkMateria;
        session()->set('pkMateria', $pkMateria);
        return $this->response->setJSON(['success' => true]);
    }

    public function delete($pkMaterial)
    {
        log_message('debug', 'Solicitud de eliminación recibida para pkMaterial: ' . $pkMaterial); // Registro para depuración
        $model = new MaterialEducativoModel();
        if ($model->delete($pkMaterial)) {
            log_message('debug', 'Eliminación exitosa para pkMaterial: ' . $pkMaterial); // Registro para depuración
            return $this->response->setJSON(['success' => true]);
        } else {
            log_message('debug', 'Error al eliminar pkMaterial: ' . $pkMaterial); // Registro para depuración
            return $this->response->setJSON(['success' => false, 'error' => 'Failed to delete material.']);
        }
    }
}
