<?php

namespace App\Controllers;

use App\Models\AvisosModel;
use App\Models\LevelsModel;

class MisAvisos extends BaseController
{
    public function __construct()
    {
        if (!session()->get('is_logged')) {
            header('Location: ' . base_url());
            exit();
        }
    }

    public function index()
    {
        $avisosModel = new AvisosModel();
        
        $fkRol = session('FK_Rol');
        $fkLevel = session('FK_Level');
        
        if ($fkRol == 2) {
            $avisos = $avisosModel->where('Estado', 1)->findAll();
        } else {
            $avisos = $avisosModel->where('Estado', 1)->where('FK_Level', $fkLevel)->findAll();
        }
    
        $data = [
            'avisos' => $avisos,
            'userType' => $fkRol
        ];
    
        return view('MisAvisos', $data);
    }
    

    public function enviarAvisoView()
    {
        $levelsModel = new LevelsModel();
        $levels = $levelsModel->findAll();

        $data = [
            'levels' => $levels
        ];

        return view('enviar_aviso', $data);
    }

    public function enviarAviso()
    {
        $avisosModel = new AvisosModel();
        $data = $this->request->getPost();

        $newAviso = [
            'Titulo' => $data['Titulo'],
            'Mensaje' => $data['Mensaje'],
            'FechaInicial' => $data['FechaInicial'],
            'FechaFinal' => $data['FechaFinal'],
            'Estado' => 1,
            'FK_User' => session('PK_User'),
            'FK_Level' => $data['FK_Level']
        ];

        if ($avisosModel->insert($newAviso)) {
            return $this->response->setJSON(['success' => true]);
        } else {
            return $this->response->setJSON(['success' => false, 'message' => 'Error al enviar el aviso.']);
        }
    }

    public function obtenerAviso($id)
    {
        $avisosModel = new AvisosModel();
        
        $fkLevel = session('FK_Level');
        
        $aviso = $avisosModel->where('FK_Level', $fkLevel)->find($id);
    
        return $this->response->setJSON($aviso);
    }
    
    public function editarAviso()
    {
        $request = \Config\Services::request();
        $avisosModel = new AvisosModel();
    
        $data = [
            'Titulo' => $request->getPost('Titulo'),
            'Mensaje' => $request->getPost('Mensaje'),
            'FechaInicial' => $request->getPost('FechaInicial'),
            'FechaFinal' => $request->getPost('FechaFinal'),
            'Estado' => 1
        ];
    
        $avisoId = $request->getPost('PK_Aviso');
    
        log_message('debug', 'Datos recibidos para editar aviso: ' . json_encode($data));
        log_message('debug', 'ID del aviso a editar: ' . $avisoId);
    
        if ($avisosModel->update($avisoId, $data)) {
            log_message('debug', 'Aviso actualizado correctamente.');
            return $this->response->setJSON(['success' => true]);
        } else {
            log_message('error', 'Error al actualizar el aviso.');
            return $this->response->setJSON(['success' => false, 'message' => 'Error al actualizar el aviso.']);
        }
    }

    public function editarAvisoView($id)
    {
        $avisosModel = new AvisosModel();
        $aviso = $avisosModel->find($id);

        $data = [
            'aviso' => $aviso
        ];

        return view('editar_aviso', $data);
    }

    public function obtenerLevels()
    {
        $levelsModel = new LevelsModel();
        $levels = $levelsModel->getAllLevels();
        return $this->response->setJSON($levels);
    }

    public function obtenerUltimosAvisos()
    {
        $avisosModel = new AvisosModel();
        
        $fkLevel = session('FK_Level');
        
        $avisos = $avisosModel->where('Estado', 1)
                              ->where('FK_Level', $fkLevel)
                              ->orderBy('FechaInicial', 'DESC')
                              ->findAll(5);
    
        return $this->response->setJSON($avisos);
    }
    
    public function obtenerCantidadAvisos()
    {
        $avisosModel = new AvisosModel();
        
        $fkLevel = session('FK_Level');
        
        $cantidad = $avisosModel->where('Estado', 1)
                                ->where('FK_Level', $fkLevel)
                                ->countAllResults();
    
        return $this->response->setJSON(['cantidad' => $cantidad]);
    }
    
    public function deleteAviso($id)
{
    $avisosModel = new AvisosModel();
    if ($avisosModel->delete($id)) {
        return $this->response->setJSON(['success' => true]);
    } else {
        return $this->response->setJSON(['success' => false, 'message' => 'Error al eliminar el aviso.']);
    }
}


}
