<?php namespace App\Controllers;

use App\Models\ExamenesModel;
use App\Models\PreguntasModel;
use App\Models\ExamenesUsuariosModel;
use App\Models\ExamenesUsuariosVistaModel;
use App\Models\AsignarExamenesGruposModel; 
use App\Models\GruposAlumnosModel;
use App\Models\RespuestasAlumnosModel;

class MisExamenesController extends BaseController
{
    protected $examenesModel;
    protected $preguntasModel;
    protected $examenesUsuariosModel;
    protected $examenesUsuariosVistaModel;
    protected $respuestasAlumnosModel;
    protected $asignarExamenesGruposModel;
    protected $gruposAlumnosModel;

    public function __construct()
    {
        if (!session()->get('is_logged')) {
            header('Location: ' . base_url());
            exit();
        }
        $this->examenesModel = new ExamenesModel();
        $this->preguntasModel = new PreguntasModel();
        $this->examenesUsuariosModel = new ExamenesUsuariosModel();
        $this->examenesUsuariosVistaModel = new ExamenesUsuariosVistaModel();
        $this->respuestasAlumnosModel = new RespuestasAlumnosModel();
        $this->asignarExamenesGruposModel = new AsignarExamenesGruposModel(); // Inicializa aquí
        $this->gruposAlumnosModel = new GruposAlumnosModel();
    }

    public function index()
    {
        $userRole = session('FK_Rol');
        $pkMateria = $this->request->getVar('materia');
        $perPage = 5;
        $currentPage = $this->request->getVar('page') ? (int)$this->request->getVar('page') : 1;

        if ($userRole == 4) {
            // Lógica para alumnos
            $data['examenesUsuariosVista'] = $this->examenesUsuariosVistaModel
                ->where('FK_User', session('PK_User'))
                ->where('FK_Materia', $pkMateria)
                ->orderBy('FechaEntrega', 'DESC')
                ->findAll();
        } else if ($userRole == 3) {
            // Lógica para maestros
            $data['examenesUsuariosVista'] = $this->examenesModel
                ->where('AsignadoPor', session('PK_User'))
                ->where('FK_Materia', $pkMateria)
                ->where('Estado !=', 'Archivado') 
                ->orderBy('FechaEntrega', 'DESC')
                ->findAll();
            
            $data['grupos'] = $this->gruposAlumnosModel->findAll();
        }

        $totalExamenes = count($data['examenesUsuariosVista']);
        $data['userRole'] = $userRole;
        $data['currentPage'] = $currentPage;
        $data['totalPages'] = ceil($totalExamenes / $perPage);
        $data['pkMateria'] = $pkMateria; 

        return view('MisExamenes', $data);
    }

    public function delete($id)
    {
        $result = $this->examenesModel->update($id, ['Estado' => 'Archivado']);
    
        if ($result) {
            return $this->response->setJSON(['status' => 'success', 'message' => 'Examen eliminado correctamente']);
        } else {
            return $this->response->setJSON(['status' => 'error', 'message' => 'El examen no se ha podido eliminar']);
        }
    }
    

    public function allExamenesMaestro()
    {
        $userId = session('PK_User');
        $userType = session('FK_Rol');
        $pkMateria = $this->request->getVar('materia');
    
        $data['examenes'] = $this->examenesModel
            ->where('AsignadoPor', $userId)
            ->where('FK_Materia', $pkMateria)
            ->findAll();
    
        $data['userType'] = $userType;
        $data['grupos'] = $this->gruposAlumnosModel->findAll();
    
        return view('AllExamenesMaestro', $data);
    }

    public function allExamenesAlumno()
    {
        $userId = session('PK_User');
        $userType = session('FK_Rol');
        $pkMateria = $this->request->getVar('materia');

        $data['examenes'] = $this->examenesUsuariosVistaModel
            ->where('FK_User', $userId)
            ->where('FK_Materia', $pkMateria)
            ->findAll();

        $data['userType'] = $userType;

        return view('AllExamenesAlumno', $data);
    }

    public function setSessionMateria()
    {
        $pkMateria = $this->request->getJSON()->pkMateria;
        session()->set('pkMateria', $pkMateria);
        return $this->response->setJSON(['status' => 'success']);
    }

    public function crear()
    {
        $pkMateria = $this->request->getVar('materia');
        $userType = session('FK_Rol');
        return view('CreandoExamen', ['pkMateria' => $pkMateria, 'userType' => $userType]);
    }

    public function store()
    {
        $userRole = session('FK_Rol');
        $data = [
            'Nombre' => $this->request->getPost('nombre'),
            'Descripción' => $this->request->getPost('descripcion'),
            'FechaEntrega' => $this->request->getPost('fecha_entrega'),
            'FK_Materia' => $this->request->getPost('fk_materia'),
            'NumeroIncisos' => $this->request->getPost('num_incisos'),
            'TiempoDuración' => $this->request->getPost('tiempo_duracion'),
            'Instrucciones' => $this->request->getPost('instrucciones'),
            'AsignadoPor' => session('PK_User')
        ];

        if ($userRole == 3) {
            $examenId = $this->examenesModel->insert($data);
        } else if ($userRole == 4) {
            $examenId = $this->examenesUsuariosModel->insert($data);
        }

        return $this->response->setJSON(['status' => 'success', 'exam_id' => $examenId]);
    }

    public function asignar_preguntas($examId)
    {
        $exam = $this->examenesModel->find($examId);

        if (!$exam) {
            throw new \CodeIgniter\Exceptions\PageNotFoundException('Examen no encontrado');
        }
        return view('AssignQuestions', [
            'examId' => $examId,
            'numIncisos' => $exam['NumeroIncisos'],
            'userType' => session('FK_Rol') 
        ]);
    }

    public function startExam($examenUsuarioId)
    {
        $fechaInicio = date('Y-m-d H:i:s');
        $this->examenesUsuariosModel->update($examenUsuarioId, [
            'FechaInicio' => $fechaInicio,
            'Estado' => 'Iniciado' 
        ]);
    
        return $this->response->setJSON(['status' => 'success']);
    }

    public function store_preguntas()
    {
        $examId = $this->request->getPost('fk_examen');
        $preguntas = $this->request->getPost('preguntas');

        if (!empty($preguntas)) {
            foreach ($preguntas as $pregunta) {
                $preguntaData = [
                    'FK_Examen' => $examId,
                    'Pregunta' => $pregunta['pregunta'],
                    'RespuestaA' => $pregunta['respuesta_a'],
                    'RespuestaB' => $pregunta['respuesta_b'],
                    'RespuestaC' => $pregunta['respuesta_c'],
                    'RespuestaD' => $pregunta['respuesta_d'],
                    'RespuestaCorrecta' => $pregunta['respuesta_correcta']
                ];
                $this->preguntasModel->insert($preguntaData);
            }
            return $this->response->setJSON(['status' => 'success']);
        }

        return $this->response->setJSON(['status' => 'error', 'message' => 'No se recibieron preguntas.']);
    }

    public function verExamen($examenUsuarioId)
    {
        $examenUsuario = $this->examenesUsuariosModel
            ->select('t_examenes_usuarios.*, t_examenes.Nombre as NombreExamen, t_examenes.NumeroIncisos, t_examenes.TiempoDuración')
            ->join('t_examenes', 't_examenes.PK_Examen = t_examenes_usuarios.FK_Examen')
            ->find($examenUsuarioId);

        if (!$examenUsuario) {
            throw new \CodeIgniter\Exceptions\PageNotFoundException('Examen no encontrado');
        }

        if ($examenUsuario['Estado'] === 'Completado') {
            return redirect()->to('/dashboard');
        }

        $preguntas = $this->preguntasModel
            ->where('FK_Examen', $examenUsuario['FK_Examen'])
            ->limit($examenUsuario['NumeroIncisos'])
            ->findAll();

        return view('Examen', [
            'examenUsuario' => $examenUsuario,
            'preguntas' => $preguntas,
            'userRole' => session('FK_Rol'), 
            'examDuration' => $examenUsuario['TiempoDuración'] 
        ]);
    }

    public function guardarRespuestas()
    {
        $respuestas = $this->request->getJSON()->respuestas;
        $examenUsuarioId = $this->request->getJSON()->examenUsuarioId;
        $userId = session('PK_User');
        $fechaRespuesta = date('Y-m-d H:i:s');
    
        if (empty((array)$respuestas)) {
            return $this->response->setJSON(['status' => 'error', 'message' => 'No se recibieron respuestas.']);
        }
    
        try {
            foreach ($respuestas as $preguntaId => $respuesta) {
                $data = [
                    'FK_ExamenUsuario' => $examenUsuarioId,
                    'FK_Pregunta' => $preguntaId,
                    'FK_Alumno' => $userId, 
                    'RespuestaSeleccionada' => $respuesta,
                    'FechaRespuesta' => $fechaRespuesta
                ];
                $this->respuestasAlumnosModel->insert($data);
            }
    
            $this->examenesUsuariosModel->update($examenUsuarioId, [
                'FechaFin' => $fechaRespuesta,
                'Estado' => 'Completado'
            ]);
    
            return $this->response->setJSON(['status' => 'success']);
        } catch (\Exception $e) {
            return $this->response->setJSON(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }

    

    public function completarExamen($examenUsuarioId)
    {
        $fechaFin = date('Y-m-d H:i:s');
        $this->examenesUsuariosModel->update($examenUsuarioId, [
            'FechaFin' => $fechaFin,
            'Estado' => 'Completado'
        ]);

        return $this->response->setJSON(['status' => 'success']);
    }

    public function verificarEstado($examenUsuarioId)
    {
        $examenUsuario = $this->examenesUsuariosModel->find($examenUsuarioId);
        if ($examenUsuario && $examenUsuario['Estado'] === 'Completado') {
            return $this->response->setJSON(['status' => 'completado']);
        } else {
            return $this->response->setJSON(['status' => 'Iniciado']);
        }
    }
    public function asignarExamenAGrupo()
    {
        $examId = $this->request->getJSON()->examId;
        $groupId = $this->request->getJSON()->groupId;
        $pkMateria = $this->request->getJSON()->pkMateria; 
    
        $data = [
            'FK_Examen' => $examId,
            'FK_Group' => $groupId,
            'FK_Materia' => $pkMateria 
        ];
    
        try {
            $this->asignarExamenesGruposModel->insert($data);
            $this->examenesModel->update($examId, ['Estado' => 'Asignado']);
            return $this->response->setJSON(['status' => 'success']);
        } catch (\Exception $e) {
            return $this->response->setJSON(['status' => 'error', 'message' => $e->getMessage()]);
        }
    }

    public function getExamDetails($examId)
{
    $examenUsuarioModel = new ExamenesUsuariosModel();
    $respuestasModel = new RespuestasAlumnosModel();
    $preguntasModel = new PreguntasModel();

    $examen = $examenUsuarioModel
        ->select('t_examenes_usuarios.*, t_examenes.Nombre as NombreExamen')
        ->join('t_examenes', 't_examenes.PK_Examen = t_examenes_usuarios.FK_Examen')
        ->find($examId);

    if (!$examen) {
        return $this->response->setJSON(['success' => false, 'message' => 'Examen no encontrado']);
    }

    $respuestas = $respuestasModel
        ->select('t_respuestas_alumnos.*, t_preguntas.Pregunta, t_preguntas.RespuestaA, t_preguntas.RespuestaB, t_preguntas.RespuestaC, t_preguntas.RespuestaD, t_preguntas.RespuestaCorrecta')
        ->join('t_preguntas', 't_preguntas.PK_Pregunta = t_respuestas_alumnos.FK_Pregunta')
        ->where('t_respuestas_alumnos.FK_ExamenUsuario', $examId)
        ->findAll();

    return $this->response->setJSON([
        'success' => true,
        'examen' => $examen,
        'respuestas' => $respuestas
    ]);
}

    
public function markAsCompleted($id)
{
    $result = $this->examenesModel->update($id, ['Estado' => 'Terminado']);

    if ($result) {
        return $this->response->setJSON(['status' => 'success', 'message' => 'Examen marcado como terminado correctamente']);
    } else {
        return $this->response->setJSON(['status' => 'error', 'message' => 'El examen no se ha podido marcar como terminado']);
    }
}

public function getExamenUsuarios($examId)
{
    $usuarios = $this->examenesUsuariosVistaModel->where('PK_Examen', $examId)->findAll();

    if ($usuarios) {
        return $this->response->setJSON(['success' => true, 'usuarios' => $usuarios]);
    } else {
        return $this->response->setJSON(['success' => false, 'message' => 'No se encontraron usuarios para este examen']);
    }
}


}
