<?php namespace App\Controllers;

use App\Models\MisTareasModel;
use CodeIgniter\Controller;
use App\Models\TareasInfoModel;
use App\Models\TareasUsuarioModel;
use App\Models\TareasModel;

class MisTareas extends Controller
{
    public function __construct()
    {
        if (!session()->get('is_logged')) {
            header('Location: ' . base_url());
            exit();
        }
    }

    private function getUserTypeText()
    {
        $userType = session('FK_Rol');
        switch ($userType) {
            case 1:
                return 'Visitante';
            case 2:
                return 'Admin';
            case 3:
                return 'Maestro';
            case 4:
                return 'Alumno';
            case 5:
                return 'Director';
            default:
                return 'Desconocido';
        }
    }

    public function index($pkMateria)
    {
        $data['pkMateria'] = $pkMateria;
        $data['userType'] = session('FK_Rol'); 
        $data['userTypeText'] = $this->getUserTypeText();
        return view('mis_tareas', $data);
    }

    private function checkUserRole()
    {
        $session = session();
        return $session->get('FK_Rol');
    }

    public function obtenerTareas($id)
    {
        if ($this->checkUserRole() == 3) {
            return $this->response->setJSON([]);
        }

        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');

        $tareas = $tareasInfoModel->where('FK_Materia', $id)
                                  ->where('FK_User', $userId)
                                  ->where('EstadoTarea', 'Completada')
                                  ->findAll();

        return $this->response->setJSON($tareas);
    }

    public function obtenerTareasPendientes($id)
    {
        if ($this->checkUserRole() == 3) {
            return $this->response->setJSON([]);
        }

        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');

        $tareas = $tareasInfoModel->where('FK_Materia', $id)
                                  ->where('FK_User', $userId)
                                  ->where('EstadoTarea', 'Pendiente')
                                  ->findAll();

        return $this->response->setJSON($tareas);
    }

    public function obtenerTareasEnProgreso($id)
    {
        if ($this->checkUserRole() == 3) {
            return $this->response->setJSON([]);
        }

        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');

        $tareas = $tareasInfoModel->where('FK_Materia', $id)
                                  ->where('FK_User', $userId)
                                  ->where('EstadoTarea', 'En Progreso')
                                  ->findAll();

        return $this->response->setJSON($tareas);
    }

    public function obtenerTareasCalificadas($id)
    {
        if ($this->checkUserRole() == 3) {
            return $this->response->setJSON([]);
        }

        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');

        $tareas = $tareasInfoModel->where('FK_Materia', $id)
                                  ->where('FK_User', $userId)
                                  ->where('EstadoTarea', 'Calificada')
                                  ->findAll();

        return $this->response->setJSON($tareas);
    }

    public function obtenerDetalleTarea($id)
    {
        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');

        $tarea = $tareasInfoModel->where('PK_TareaUsuario', $id)->first();

        if ($tarea) {
            return $this->response->setJSON($tarea);
        } else {
            return $this->response->setJSON(['error' => 'Tarea no encontrada'], 404);
        }
    }

    public function actualizarEstado()
    {
        $tareasUsuarioModel = new TareasUsuarioModel();
        $request = \Config\Services::request();

        $data = json_decode($request->getBody(), true);
        $tareaId = $data['PK_TareaUsuario'];
        $estado = $data['Estado'];
        $fechaTareaRecibida = $data['FechaTareaRecibida'];

        log_message('debug', 'Estado recibido: ' . $estado);
        log_message('debug', 'Tarea ID recibido: ' . $tareaId);
        log_message('debug', 'FechaTareaRecibida: ' . $fechaTareaRecibida);

        if (empty($estado)) {
            log_message('error', 'El estado está vacío');
            return $this->response->setJSON(['success' => false, 'message' => 'El estado no puede estar vacío.']);
        }

        $updateData = [
            'Estado' => $estado,
            'FechaTareaRecibida' => $fechaTareaRecibida
        ];

        if ($tareasUsuarioModel->where('PK_TareaUsuario', $tareaId)->set($updateData)->update()) {
            log_message('debug', 'Actualización exitosa para la tarea con ID: ' . $tareaId);
            return $this->response->setJSON(['success' => true, 'message' => 'Estado de la tarea actualizado.']);
        } else {
            log_message('error', 'Error al actualizar la tarea con ID: ' . $tareaId);
            return $this->response->setJSON(['success' => false, 'message' => 'Error al actualizar el estado de la tarea.']);
        }
    }

    public function todasMisTareasMaestro($pkMateria, $page = 1)
    {
        $tareasModel = new TareasModel();
        $userId = session('PK_User');
        $perPage = 5;
    
        $offset = ($page - 1) * $perPage;
        $tareas = $tareasModel->where('AsignadoPor', $userId)
                              ->where('FK_Materia', $pkMateria)
                              ->where('Estado !=', 'Archivada')
                              ->findAll($perPage, $offset);
        $totalTareas = $tareasModel->where('AsignadoPor', $userId)
                                   ->where('FK_Materia', $pkMateria)
                                   ->where('Estado !=', 'Archivada')
                                   ->countAllResults();
    
        log_message('debug', 'Tareas recuperadas:', $tareas); 
    
        return $this->response->setJSON([
            'tareas' => $tareas,
            'total' => $totalTareas,
            'perPage' => $perPage,
            'currentPage' => $page
        ]);
    }
    

    public function obtenerDetalleTareaMaestro($id)
    {
        $tareasModel = new TareasModel();
        $userId = session('PK_User');

        $tarea = $tareasModel->where('PK_Tarea', $id)->first();

        if ($tarea) {
            return $this->response->setJSON($tarea);
        } else {
            return $this->response->setJSON(['error' => 'Tarea no encontrada'], 404);
        }
    }

    public function editarTarea()
    {
        $request = \Config\Services::request();
        $misTareasModel = new MisTareasModel();
    
        $data = $request->getPost();
        $tareaId = $data['PK_Tarea'];
    
        $tareaData = [
            'Nombre' => $data['taskTitle'],
            'Descripción' => $data['taskDescription'],
            'FechaEntrega' => $data['taskDueDate'],
            'FK_Materia' => $data['materiaId'],
            'AsignadoPor' => $data['asignadoPor']
        ];
    
        if ($misTareasModel->update($tareaId, $tareaData)) {
            return $this->response->setJSON(['status' => 'success']);
        } else {
            return $this->response->setJSON(['status' => 'error']);
        }
    }
    

    public function archivarTarea()
    {
        $request = \Config\Services::request();
        $misTareasModel = new MisTareasModel();
    
        $data = json_decode($request->getBody(), true);
        $tareaId = $data['PK_Tarea'];
    
        $updateData = [
            'Estado' => 'Archivada'
        ];
    
        if ($misTareasModel->where('PK_Tarea', $tareaId)->set($updateData)->update()) {
            return $this->response->setJSON(['success' => true, 'message' => 'Tarea archivada exitosamente.']);
        } else {
            return $this->response->setJSON(['success' => false, 'message' => 'Error al archivar la tarea.']);
        }
    }
    

    public function calificarTareas($pkMateria)
    {
        $data['pkMateria'] = $pkMateria;
        $data['userTypeText'] = $this->getUserTypeText();
        return view('CalificarTareas', $data);
    }

    public function obtenerTareasInfo($pkMateria)
    {
        $query = $this->request->getGet('query');
        $page = $this->request->getGet('page') ?: 1;
        $perPage = $this->request->getGet('perPage') ?: 5;

        $tareasInfoModel = new TareasInfoModel();

        if ($query) {
            $tareasInfoModel->like('NombreTarea', $query);
        }

        $total = $tareasInfoModel->where('FK_Materia', $pkMateria)->countAllResults(false);
        $tareas = $tareasInfoModel->where('FK_Materia', $pkMateria)->findAll($perPage, ($page - 1) * $perPage);

        return $this->response->setJSON([
            'tareas' => $tareas,
            'total' => $total,
            'perPage' => $perPage,
            'currentPage' => $page
        ]);
    }

    public function calificarTarea()
    {
        $tareasInfoModel = new TareasInfoModel();
        $request = \Config\Services::request();

        $data = json_decode($request->getBody(), true);
        $tareaId = $data['PK_TareaUsuario'];
        $calificacion = $data['Calificacion'];
        $comentarios = $data['Comentarios'];

        $updateData = [
            'Calificacion' => $calificacion,
            'Comentarios' => $comentarios,
            'FechaCalificacion' => date('Y-m-d H:i:s'),
            'EstadoTarea' => 'Calificada'
        ];

        if ($tareasInfoModel->update($tareaId, $updateData)) {
            return $this->response->setJSON(['success' => true, 'message' => 'Calificación guardada exitosamente.']);
        } else {
            return $this->response->setJSON(['success' => false, 'message' => 'Error al guardar la calificación.']);
        }
    }

    public function misTareasMaestro($pkMateria, $pkTarea)
    {
        $userType = session('FK_Rol');
        if ($userType != 3) {
            return redirect()->to('/dashboard');
        }
    
        $tareasModel = new TareasModel();
        $tarea = $tareasModel->where('PK_Tarea', $pkTarea)->first();
    
        if (!$tarea) {
            return redirect()->to('/mis_tareas/'.$pkMateria)->with('error', 'Tarea no encontrada.');
        }
    
        $data['pkMateria'] = $pkMateria;
        $data['userType'] = $userType;
        $data['userTypeText'] = $this->getUserTypeText();
        $data['tarea'] = $tarea;
    
        return view('MisTareasMaestro', $data);
    }
    

    public function eliminarArchivo()
    {
        $tareasUsuarioModel = new TareasUsuarioModel();
        $request = \Config\Services::request();
    
        $data = json_decode($request->getBody(), true);
        $tareaId = $data['tarea_id'];
    
        // Actualizar la base de datos para eliminar la referencia del archivo
        $updateData = [
            'Archivo' => null // Elimina la referencia del archivo
        ];
    
        if ($tareasUsuarioModel->where('PK_TareaUsuario', $tareaId)->set($updateData)->update()) {
            return $this->response->setJSON(['success' => true, 'message' => 'Archivo eliminado exitosamente de la base de datos.']);
        } else {
            return $this->response->setJSON(['success' => false, 'message' => 'Error al eliminar la referencia del archivo en la base de datos.']);
        }
    }
    

}
