<?php namespace App\Controllers;

use CodeIgniter\Controller;
use App\Models\TareasInfoModel;

class Tareas extends Controller
{
    public function detalle($pkMateria, $nombreTarea)
    {
        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');
        $tarea = $tareasInfoModel->where('FK_User', $userId)->where('NombreTarea', urldecode($nombreTarea))->first();

        if (!$tarea) {
            throw new \CodeIgniter\Exceptions\PageNotFoundException('Tarea no encontrada: ' . $nombreTarea);
        }

        $data = [
            'pkMateria' => $pkMateria,
            'nombreTarea' => $nombreTarea,
            'tarea' => $tarea
        ];

        return view('detalle_tarea', $data);
    }

    public function uploadFile()
    {
        $tareasInfoModel = new TareasInfoModel();
        $tareaId = $this->request->getPost('tarea_id');
        $userId = session('PK_User');
        
        // Verificar que la tarea pertenece al usuario actual
        $tarea = $tareasInfoModel->where('FK_User', $userId)->find($tareaId);
        if (!$tarea) {
            return $this->response->setJSON(['success' => false, 'message' => 'Tarea no encontrada o no pertenece al usuario actual.']);
        }

        // Obtener el archivo subido
        $file = $this->request->getFile('file');
        
        // Tipos de archivo permitidos
        $allowedTypes = ['image/jpeg', 'image/png', 'application/pdf', 'text/plain', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document'];
        
        if ($file->isValid() && !$file->hasMoved() && in_array($file->getMimeType(), $allowedTypes)) {
            // Mover el archivo a una ubicación segura dentro de tu proyecto
            $newName = $file->getRandomName();
            $file->move(FCPATH . 'uploads', $newName);

            // Guardar el nombre del archivo en la base de datos
            $tareasInfoModel->update($tareaId, ['Archivo' => $newName]);

            // Devolver una respuesta JSON para manejar con JavaScript
            return $this->response->setJSON(['success' => true, 'message' => 'Archivo subido correctamente.']);
        } else {
            return $this->response->setJSON(['success' => false, 'message' => 'Error al subir el archivo. Tipo de archivo no permitido.']);
        }
    }

    public function getTarea($id)
    {
        $tareasInfoModel = new TareasInfoModel();
        $userId = session('PK_User');
        $tarea = $tareasInfoModel->where('FK_User', $userId)->find($id);

        if ($tarea) {
            return $this->response->setJSON($tarea);
        } else {
            return $this->response->setJSON(['error' => 'Tarea no encontrada'], 404);
        }
    }

    public function deleteFile()
    {
        $tareasInfoModel = new TareasInfoModel();
        $tareaId = $this->request->getPost('tarea_id');
        $archivo = $this->request->getPost('archivo');
        $userId = session('PK_User');

        // Verificar que la tarea pertenece al usuario actual
        $tarea = $tareasInfoModel->where('FK_User', $userId)->find($tareaId);
        if (!$tarea) {
            return $this->response->setJSON(['success' => false, 'message' => 'Tarea no encontrada o no pertenece al usuario actual.']);
        }

        // Eliminar el archivo del sistema
        if (file_exists(FCPATH . 'uploads/' . $archivo)) {
            unlink(FCPATH . 'uploads/' . $archivo);
        }

        // Actualizar la base de datos
        $tareasInfoModel->update($tareaId, ['Archivo' => null]);

        // Devolver una respuesta JSON para manejar con JavaScript
        return $this->response->setJSON(['success' => true, 'message' => 'Archivo eliminado correctamente.']);
    }
}
