const perPage = 5; // Define cuántos registros por página

document.addEventListener('DOMContentLoaded', function() {
    fetchCalificaciones();
    document.getElementById('searchInput').addEventListener('input', function() {
        fetchCalificaciones(this.value);
    });

    document.getElementById('calificarTareaForm').addEventListener('submit', function(e) {
        e.preventDefault();
        if (validarCalificacion()) {
            calificarTarea();
        } else {
            Swal.fire({
                type: 'error',
                title: 'Calificación inválida',
                text: 'La calificación debe ser un número decimal con un incremento de 0.1.'
            });
        }
    });

    $('#calificacionesTable').DataTable({
        ordering: false, 
        paging: false, 
        info: false,   
        searching: false 
    });
});

function fetchCalificaciones(query = '', page = 1) {
    fetch(`${baseUrl}/mis_tareas/obtenerTareasInfo/${pkMateria}?query=${query}&page=${page}&perPage=${perPage}`)
        .then(response => response.json())
        .then(data => {
            var calificacionesList = document.getElementById('calificacionesList');
            calificacionesList.innerHTML = '';
            data.tareas.forEach(function(tarea) {
                var fechaTareaRecibidaFormateada = formatearFecha(tarea.FechaTareaRecibida);
                var fechaCalificacionFormateada = tarea.FechaCalificacion ? formatearFecha(tarea.FechaCalificacion) : 'Aún sin calificar';
                var comentarios = tarea.Comentarios ? tarea.Comentarios : ''; // Mostrar vacío si es NULL
                var archivo = tarea.Archivo ? `<i class="material-icons" onclick="verArchivo('${tarea.Archivo}')">attach_file</i>` : '';
                var listItem = document.createElement('tr');
                listItem.innerHTML = `
                    <td>${tarea.NombreTarea}</td>
                    <td>${tarea.NombreUsuario}</td>
                    <td>${tarea.NombreMateria}</td>
                    <td>${tarea.Calificacion}</td>
                    <td>${comentarios}</td>
                    <td>${fechaCalificacionFormateada}</td>
                    <td>${archivo}</td>
                    <td>${tarea.EstadoTarea}</td>
                    <td>${fechaTareaRecibidaFormateada}</td>
                    <td>
                        <button class="btn btn-primary btn-link btn-sm" onclick="openCalificarModal(${tarea.PK_TareaUsuario})">
                            <i class="material-icons">edit</i>
                        </button>
                    </td>
                `;
                calificacionesList.appendChild(listItem);
            });
            renderPagination(data.total, data.perPage, data.currentPage);
        })
        .catch(error => console.error('Error al obtener las tareas:', error));
}

function formatearFecha(fecha) {
    if (!fecha) return ''; // Manejar el caso de fechas nulas
    var opciones = { weekday: 'long', day: 'numeric', month: 'long' };
    var fechaObj = new Date(fecha);
    return fechaObj.toLocaleDateString('es-ES', opciones);
}

function openCalificarModal(tareaId) {
    document.getElementById('tareaId').value = tareaId;
    $('#calificacionesModal').modal('show');
}

function validarCalificacion() {
    var calificacion = parseFloat(document.getElementById('calificacion').value);
    return calificacion >= 0 && calificacion <= 10 && (calificacion * 10) % 1 === 0;
}

function calificarTarea() {
    var tareaId = document.getElementById('tareaId').value;
    var calificacion = parseFloat(document.getElementById('calificacion').value);
    var comentarios = document.getElementById('comentarios').value;

    fetch(`${baseUrl}/mis_tareas/calificarTarea`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({
            PK_TareaUsuario: tareaId,
            Calificacion: calificacion,
            Comentarios: comentarios
        })
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            Swal.fire({
                type: 'success',
                title: 'Calificación guardada',
                text: 'Calificación guardada exitosamente.'
            }).then(() => {
                $('#calificacionesModal').modal('hide');
                location.reload(); // Recargar la página
            });
        } else {
            Swal.fire({
                type: 'error',
                title: 'Error',
                text: 'Error al guardar la calificación.'
            });
        }
    })
    .catch(error => {
        console.error('Error al calificar la tarea:', error);
        Swal.fire({
            type: 'error',
            title: 'Error',
            text: 'Hubo un problema al calificar la tarea.'
        });
    });
}

function verArchivo(archivo) {
    var archivoModal = $('#archivoModal');
    var archivoImg = document.getElementById('archivoImg');
    var archivoIframe = document.getElementById('archivoIframe');
    var extension = archivo.split('.').pop().toLowerCase();
    var archivoUrl = `${baseUrl}/uploads/${archivo}`;

    if (['jpg', 'jpeg', 'png', 'gif'].includes(extension)) {
        archivoImg.src = archivoUrl;
        archivoImg.style.display = 'block';
        archivoIframe.style.display = 'none';
    } else {
        archivoIframe.src = archivoUrl;
        archivoIframe.style.display = 'block';
        archivoImg.style.display = 'none';
    }

    archivoModal.modal('show');
}

function renderPagination(total, perPage, currentPage) {
    const totalPages = Math.ceil(total / perPage);
    const pagination = document.getElementById('pagination');
    pagination.innerHTML = '';

    for (let i = 1; i <= totalPages; i++) {
        const li = document.createElement('li');
        li.className = `page-item ${i === currentPage ? 'active' : ''}`;
        li.innerHTML = `<a class="page-link" href="javascript:void(0)" onclick="fetchCalificaciones(document.getElementById('searchInput').value, ${i})">${i}</a>`;
        pagination.appendChild(li);
    }
}

$(document).ready(function() {
    $().ready(function() {
      $sidebar = $('.sidebar');

      $sidebar_img_container = $sidebar.find('.sidebar-background');

      $full_page = $('.full-page');

      $sidebar_responsive = $('body > .navbar-collapse');

      window_width = $(window).width();

      fixed_plugin_open = $('.sidebar .sidebar-wrapper .nav li.active a p').html();

      if (window_width > 767 && fixed_plugin_open == 'Dashboard') {
        if ($('.fixed-plugin .dropdown').hasClass('show-dropdown')) {
          $('.fixed-plugin .dropdown').addClass('open');
        }

      }

      $('.fixed-plugin a').click(function(event) {
        // Alex if we click on switch, stop propagation of the event, so the dropdown will not be hide, otherwise we set the  section active
        if ($(this).hasClass('switch-trigger')) {
          if (event.stopPropagation) {
            event.stopPropagation();
          } else if (window.event) {
            window.event.cancelBubble = true;
          }
        }
      });

      $('.fixed-plugin .active-color span').click(function() {
        $full_page_background = $('.full-page-background');

        $(this).siblings().removeClass('active');
        $(this).addClass('active');

        var new_color = $(this).data('color');

        if ($sidebar.length != 0) {
          $sidebar.attr('data-color', new_color);
        }

        if ($full_page.length != 0) {
          $full_page.attr('filter-color', new_color);
        }

        if ($sidebar_responsive.length != 0) {
          $sidebar_responsive.attr('data-color', new_color);
        }
      });

      $('.fixed-plugin .background-color .badge').click(function() {
        $(this).siblings().removeClass('active');
        $(this).addClass('active');

        var new_color = $(this).data('background-color');

        if ($sidebar.length != 0) {
          $sidebar.attr('data-background-color', new_color);
        }
      });

      $('.fixed-plugin .img-holder').click(function() {
        $full_page_background = $('.full-page-background');

        $(this).parent('li').siblings().removeClass('active');
        $(this).parent('li').addClass('active');


        var new_image = $(this).find("img").attr('src');

        if ($sidebar_img_container.length != 0 && $('.switch-sidebar-image input:checked').length != 0) {
          $sidebar_img_container.fadeOut('fast', function() {
            $sidebar_img_container.css('background-image', 'url("' + new_image + '")');
            $sidebar_img_container.fadeIn('fast');
          });
        }

        if ($full_page_background.length != 0 && $('.switch-sidebar-image input:checked').length != 0) {
          var new_image_full_page = $('.fixed-plugin li.active .img-holder').find('img').data('src');

          $full_page_background.fadeOut('fast', function() {
            $full_page_background.css('background-image', 'url("' + new_image_full_page + '")');
            $full_page_background.fadeIn('fast');
          });
        }

        if ($('.switch-sidebar-image input:checked').length == 0) {
          var new_image = $('.fixed-plugin li.active .img-holder').find("img").attr('src');
          var new_image_full_page = $('.fixed-plugin li.active .img-holder').find('img').data('src');

          $sidebar_img_container.css('background-image', 'url("' + new_image + '")');
          $full_page_background.css('background-image', 'url("' + new_image_full_page + '")');
        }

        if ($sidebar_responsive.length != 0) {
          $sidebar_responsive.css('background-image', 'url("' + new_image + '")');
        }
      });

      $('.switch-sidebar-image input').change(function() {
        $full_page_background = $('.full-page-background');

        $input = $(this);

        if ($input.is(':checked')) {
          if ($sidebar_img_container.length != 0) {
            $sidebar_img_container.fadeIn('fast');
            $sidebar.attr('data-image', '#');
          }

          if ($full_page_background.length != 0) {
            $full_page_background.fadeIn('fast');
            $full_page.attr('data-image', '#');
          }

          background_image = true;
        } else {
          if ($sidebar_img_container.length != 0) {
            $sidebar.removeAttr('data-image');
            $sidebar_img_container.fadeOut('fast');
          }

          if ($full_page_background.length != 0) {
            $full_page.removeAttr('data-image', '#');
            $full_page_background.fadeOut('fast');
          }

          background_image = false;
        }
      });

      $('.switch-sidebar-mini input').change(function() {
        $body = $('body');

        $input = $(this);

        if (md.misc.sidebar_mini_active == true) {
          $('body').removeClass('sidebar-mini');
          md.misc.sidebar_mini_active = false;

          $('.sidebar .sidebar-wrapper, .main-panel').perfectScrollbar();

        } else {

          $('.sidebar .sidebar-wrapper, .main-panel').perfectScrollbar('destroy');

          setTimeout(function() {
            $('body').addClass('sidebar-mini');

            md.misc.sidebar_mini_active = true;
          }, 300);
        }

        // we simulate the window Resize so the charts will get updated in realtime.
        var simulateWindowResize = setInterval(function() {
          window.dispatchEvent(new Event('resize'));
        }, 180);

        // we stop the simulation of Window Resize after the animations are completed
        setTimeout(function() {
          clearInterval(simulateWindowResize);
        }, 1000);

      });
    });
  });