document.addEventListener('DOMContentLoaded', function() {
    const userRole = window.userRole;

    if (userRole !== '4') {
        return; 
    }

    function formatDate(dateString) {
        const options = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
        const date = new Date(dateString);
        return date.toLocaleDateString('es-ES', options);
    }

    function formatDateTime(dateString) {
        const optionsDate = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
        const optionsTime = { hour: '2-digit', minute: '2-digit' };
        const date = new Date(dateString);
        return date.toLocaleDateString('es-ES', optionsDate) + ' ' + date.toLocaleTimeString('es-ES', optionsTime);
    }

    const examenesDataElement = document.getElementById('examenes-data');
    const examenesTbody = document.getElementById('examenes-tbody-alumno');
    const searchInput = document.getElementById('search-input-alumno');
    const paginationContainer = document.getElementById('pagination-container-alumno');
    const perPage = 5;

    if (examenesDataElement && examenesTbody && searchInput && paginationContainer) {
        let examenes = JSON.parse(examenesDataElement.textContent);
        let filteredExamenes = examenes;
        let currentPage = 1;

        function renderExamenes(filteredExamenes, page = 1) {
            examenesTbody.innerHTML = '';
            const start = (page - 1) * perPage;
            const end = page * perPage;
            const paginatedExamenes = filteredExamenes.slice(start, end);
        
            if (paginatedExamenes.length > 0) {
                paginatedExamenes.forEach(examen => {
                    const tr = document.createElement('tr');
                    tr.innerHTML = `
                        <td data-label="Nombre del examen">${examen.NombreExamen}</td>
                        <td data-label="Fecha de entrega">${formatDate(examen.FechaEntrega)}</td>
                        <td data-label="Estado">${examen.Estado}</td>
                        <td data-label="Acciones" class="no-hover">
                            ${examen.Estado === 'Asignado' ? `<button id="start-exam-${examen.PK_ExamenUsuario}" class="btn btn-rose btn-sm" onclick="openStartExamModal(${examen.PK_ExamenUsuario})"><i class="material-icons">school</i></button>` : ''}
                            ${examen.Estado === 'Iniciado' ? `<button id="continue-exam-${examen.PK_ExamenUsuario}" class="btn btn-rose btn-sm" onclick="continueExam(${examen.PK_ExamenUsuario})"><i class="material-icons">play_arrow</i></button>` : ''}
                            ${examen.Estado === 'Completado' ? `<button id="view-grade-${examen.PK_ExamenUsuario}" class="btn btn-rose btn-sm" onclick="openViewGradeModal(${examen.PK_ExamenUsuario})"><i class="material-icons">visibility</i></button>` : ''}
                        </td>
                    `;
                    examenesTbody.appendChild(tr);
                });
                paginationContainer.style.display = 'block';
            } else {
                const tr = document.createElement('tr');
                const td = document.createElement('td');
                td.colSpan = 4; 
                td.textContent = 'No hay exámenes disponibles.';
                td.style.textAlign = 'center';
                tr.appendChild(td);
                examenesTbody.appendChild(tr);
                paginationContainer.style.display = 'none';
            }
        
            renderPagination(filteredExamenes.length, page);
        }
        
        function renderPagination(totalItems, currentPage) {
            const totalPages = Math.ceil(totalItems / perPage);
            const pagination = document.querySelector('.pagination');
            pagination.innerHTML = '';

            for (let i = 1; i <= totalPages; i++) {
                const li = document.createElement('li');
                li.classList.add('page-item');
                if (i === currentPage) {
                    li.classList.add('active');
                }
                const a = document.createElement('a');
                a.classList.add('page-link');
                a.textContent = i;
                a.setAttribute('data-page', i);
                a.href = '#';
                li.appendChild(a);
                pagination.appendChild(li);
            }
        }

        renderExamenes(filteredExamenes);

        searchInput.addEventListener('input', function() {
            const searchTerm = searchInput.value.toLowerCase();
            filteredExamenes = examenes.filter(examen => 
                examen.NombreExamen.toLowerCase().includes(searchTerm)
            );
            renderExamenes(filteredExamenes);
        });

        clearSearchButton.addEventListener('click', function() {
            searchInput.value = '';
            filteredExamenes = examenes;
            renderExamenes(filteredExamenes);
        });

        document.querySelector('.pagination').addEventListener('click', function(event) {
            if (event.target.tagName === 'A') {
                event.preventDefault();
                currentPage = Number(event.target.getAttribute('data-page'));
                renderExamenes(filteredExamenes, currentPage);
            }
        });
    } else {
        console.error("Uno o más elementos DOM no se encontraron.");
    }
});

function openStartExamModal(examId) {
    const startExamModal = document.getElementById('startExamModal');
    const understoodCheckbox = document.getElementById('understoodCheckbox');
    const confirmStartExamButton = document.getElementById('confirmStartExam');

    understoodCheckbox.checked = false;
    confirmStartExamButton.disabled = true;

    understoodCheckbox.addEventListener('change', function() {
        confirmStartExamButton.disabled = !understoodCheckbox.checked;
    });

    confirmStartExamButton.onclick = function() {
        startExam(examId);
    };

    $('#startExamModal').modal('show');
}

function startExam(examId) {
    fetch(`${window.baseUrl}/misexamenes/startExam/${examId}`, {
        method: 'GET',
        headers: {
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        }
    })
    .then(response => {
        if (!response.ok) {
            throw new Error('Error al iniciar el examen');
        }
        document.getElementById(`start-exam-${examId}`).disabled = true;
        window.location.href = `${window.baseUrl}/misexamenes/verExamen/${examId}`;
    })
    .catch(error => {
        console.error(error.message);
        Swal.fire('Hubo un error al iniciar el examen. Por favor, inténtalo de nuevo.');
    });
}

function continueExam(examId) {
    window.location.href = `${window.baseUrl}/misexamenes/verExamen/${examId}`;
}

function openViewGradeModal(examId) {
    fetch(`${window.baseUrl}/misexamenes/getExamDetails/${examId}`, {
        method: 'GET',
        headers: {
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        }
    })
    .then(response => response.json())
    .then(data => {
        if (!data.success) {
            throw new Error('Error al obtener detalles del examen');
        }

        const getAnswerText = (respuesta, pregunta) => {
            switch (respuesta) {
                case 'a': return pregunta.RespuestaA;
                case 'b': return pregunta.RespuestaB;
                case 'c': return pregunta.RespuestaC;
                case 'd': return pregunta.RespuestaD;
                default: return 'N/A';
            }
        };

        const modalContent = document.getElementById('viewGradeModalContent');
        modalContent.innerHTML = `
            <h5>Calificación: ${data.examen.Calificacion}</h5>
            ${data.respuestas.map(r => `
                <p>Pregunta: ${r.Pregunta}</p>
                <p>Tu respuesta: ${getAnswerText(r.RespuestaSeleccionada, r)}</p>
                <p>Respuesta correcta: ${getAnswerText(r.RespuestaCorrecta, r)}</p>
                <hr>
            `).join('')}
        `;

        $('#viewGradeModal').modal('show');
    })
    .catch(error => {
        console.error(error.message);
        Swal.fire('Hubo un error al obtener los detalles del examen. Por favor, inténtalo de nuevo.');
    });
}
