document.addEventListener('DOMContentLoaded', function() {
    const userRole = window.userRole;

    if (userRole !== '3') {
        return; 
    }

    function formatDate(dateString) {
        const options = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
        const date = new Date(dateString);
        return date.toLocaleDateString('es-ES', options);
    }

    function formatDateTime(dateString) {
        const optionsDate = { year: 'numeric', month: 'short', day: 'numeric' };
        const optionsTime = { hour: '2-digit', minute: '2-digit' };
        const date = new Date(dateString);
        return date.toLocaleDateString('es-ES', optionsDate) + '<br>' + date.toLocaleTimeString('es-ES', optionsTime);
    }
    
    const examenesDataElement = document.getElementById('examenes-data');
    const examenesTbody = document.getElementById('examenes-tbody-maestro');
    const searchInput = document.getElementById('search-input-maestro');
    const clearSearchButton = document.getElementById('clear-search-maestro');
    const filterTerminadoButton = document.getElementById('filter-terminado-maestro');
    const filterAsignadoButton = document.getElementById('filter-asignado-maestro');
    const filterRecursarButton = document.getElementById('filter-recursar-maestro');
    const paginationContainer = document.getElementById('pagination-container-maestro');
    const perPage = 5;

    if (examenesDataElement) {
        let examenes = JSON.parse(examenesDataElement.textContent);
        let filteredExamenes = examenes.filter(examen => examen.Estado !== 'Archivado'); 
        let currentPage = 1;

        function renderExamenes(filteredExamenes, page = 1) {
            examenesTbody.innerHTML = '';
            const start = (page - 1) * perPage;
            const end = page * perPage;
            const paginatedExamenes = filteredExamenes.slice(start, end);
        
            if (paginatedExamenes.length > 0) {
                paginatedExamenes.forEach(examen => {
                    const tr = document.createElement('tr');
                    tr.innerHTML = `
                        <td>${examen.Nombre}</td>
                        <td>${formatDateTime(examen.FechaCreación)}</td>
                        <td>${formatDate(examen.FechaEntrega)}</td>
                        <td>${examen.Estado}</td>
                        <td class="no-hover">
                            <button class="btn btn-danger btn-link btn-sm" onclick="confirmDeleteExamen(${examen.PK_Examen})">
                                <i class="material-icons">delete</i>
                            </button>
                            ${examen.Estado === 'Sin-Asignar' ? `<button class="btn btn-rose btn-sm" onclick="openAssignGroupModal(${examen.PK_Examen})"><i class="material-icons">group_add</i></button>` : ''}
                            ${examen.Estado === 'Asignado' ? `<button class="btn btn-success btn-sm" onclick="markAsCompleted(${examen.PK_Examen})"><i class="material-icons">check</i></button>` : ''}
                            <button class="btn btn-info btn-link btn-sm" onclick="openExamenUsuariosModal(${examen.PK_Examen})">
                                <i class="material-icons">people</i>
                            </button>
                        </td>
                    `;
                    examenesTbody.appendChild(tr);
                });
                paginationContainer.style.display = 'block';
            } else {
                const tr = document.createElement('tr');
                const td = document.createElement('td');
                td.colSpan = 5;
                td.textContent = 'No hay exámenes disponibles.';
                td.style.textAlign = 'center';
                tr.appendChild(td);
                examenesTbody.appendChild(tr);
                paginationContainer.style.display = 'none';
            }
        
            renderPagination(filteredExamenes.length, page);
        }
        
        
        function renderPagination(totalItems, currentPage) {
            const totalPages = Math.ceil(totalItems / perPage);
            const pagination = document.querySelector('.pagination');
            pagination.innerHTML = '';

            for (let i = 1; i <= totalPages; i++) {
                const li = document.createElement('li');
                li.classList.add('page-item');
                if (i === currentPage) {
                    li.classList.add('active');
                }
                const a = document.createElement('a');
                a.classList.add('page-link');
                a.textContent = i;
                a.setAttribute('data-page', i);
                a.href = '#';
                li.appendChild(a);
                pagination.appendChild(li);
            }
        }

        renderExamenes(filteredExamenes);

        searchInput.addEventListener('input', function() {
            const searchTerm = searchInput.value.toLowerCase();
            filteredExamenes = examenes.filter(examen => 
                examen.Nombre.toLowerCase().includes(searchTerm) && examen.Estado !== 'Archivado' 
            );
            renderExamenes(filteredExamenes);
        });

        clearSearchButton.addEventListener('click', function() {
            searchInput.value = '';
            filteredExamenes = examenes.filter(examen => examen.Estado !== 'Archivado'); 
            renderExamenes(filteredExamenes);
        });

        filterTerminadoButton.addEventListener('click', function() {
            const isActive = filterTerminadoButton.classList.toggle('btn-picked');
            if (isActive) {
                filteredExamenes = examenes.filter(examen => examen.Estado === 'Terminado' && examen.Estado !== 'Archivado'); 
            } else {
                filteredExamenes = examenes.filter(examen => examen.Estado !== 'Archivado'); 
            }
            renderExamenes(filteredExamenes);
        });

        filterAsignadoButton.addEventListener('click', function() {
            const isActive = filterAsignadoButton.classList.toggle('btn-picked');
            if (isActive) {
                filteredExamenes = examenes.filter(examen => examen.Estado === 'Asignado' && examen.Estado !== 'Archivado');
            } else {
                filteredExamenes = examenes.filter(examen => examen.Estado !== 'Archivado'); 
            }
            renderExamenes(filteredExamenes);
        });

        filterRecursarButton.addEventListener('click', function() {
            const isActive = filterRecursarButton.classList.toggle('btn-picked');
            if (isActive) {
                filteredExamenes = examenes.filter(examen => examen.Estado === 'Recursar' && examen.Estado !== 'Archivado');
            } else {
                filteredExamenes = examenes.filter(examen => examen.Estado !== 'Archivado'); 
            }
            renderExamenes(filteredExamenes);
        });

        document.querySelector('.pagination').addEventListener('click', function(event) {
            if (event.target.tagName === 'A') {
                event.preventDefault();
                currentPage = Number(event.target.getAttribute('data-page'));
                renderExamenes(filteredExamenes, currentPage);
            }
        });
    }
});


function confirmDeleteExamen(id) {
    Swal.fire({
        title: '¿Seguro de eliminar este examen?',
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#3085d6',
        cancelButtonColor: '#d33',
        confirmButtonText: 'Sí, eliminar',
        cancelButtonText: 'Cancelar'
    }).then((result) => {
        if (result.isConfirmed) {
            archiveExamen(id);
        }
    });
}

function archiveExamen(id) {
    fetch(`${window.baseUrl}/misexamenes/delete/${id}`, {
        method: 'POST', 
        headers: {
            'Content-Type': 'application/json',
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        }
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            Swal.fire(
                'Eliminado',
                'Examen eliminado correctamente',
                'success'
            ).then(() => {
                location.reload();
            });
        } else {
            Swal.fire(
                'Error',
                'El examen no se ha podido eliminar',
                'error'
            );
        }
    })
    .catch(error => {
        Swal.fire(
            'Error',
            'El examen no se ha podido eliminar',
            'error'
        );
    });
}

function openAssignGroupModal(examId) {
    const assignGroupModal = document.getElementById('assignGroupModal');
    const confirmAssignGroupButton = document.getElementById('confirmAssignGroup');

    confirmAssignGroupButton.onclick = function() {
        const groupId = document.getElementById('groupSelect').value;
        assignExamToGroup(examId, groupId);
    };

    $('#assignGroupModal').modal('show');
}

function assignExamToGroup(examId, groupId) {
    const pkMateria = window.pkMateria; 
    fetch(`${window.baseUrl}/misexamenes/asignarExamenAGrupo`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        },
        body: JSON.stringify({ examId, groupId, pkMateria }) 
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            Swal.fire({
                icon: 'success',
                title: 'Examen asignado',
                text: 'El examen ha sido asignado al grupo correctamente.',
                showConfirmButton: false,
                timer: 2000
            }).then(() => {
                location.reload();
            });
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: data.message || 'Hubo un problema al asignar el examen al grupo. Inténtalo nuevamente.',
                showConfirmButton: true
            });
        }
    })
    .catch(error => {
        console.error('Error:', error);
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: 'Hubo un problema al asignar el examen al grupo. Inténtalo nuevamente.',
            showConfirmButton: true
        });
    });
}

function markAsCompleted(id) {
    fetch(`${window.baseUrl}/misexamenes/markAsCompleted/${id}`, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        }
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            Swal.fire(
                'Completado',
                'El examen ha sido marcado como terminado.',
                'success'
            ).then(() => {
                location.reload();
            });
        } else {
            Swal.fire(
                'Error',
                'El examen no se ha podido marcar como terminado.',
                'error'
            );
        }
    })
    .catch(error => {
        Swal.fire(
            'Error',
            'El examen no se ha podido marcar como terminado.',
            'error'
        );
    });
}

function openExamenUsuariosModal(examId) {
    fetch(`${window.baseUrl}/misexamenes/getExamenUsuarios/${examId}`, {
        method: 'GET',
        headers: {
            'X-Requested-With': 'XMLHttpRequest',
            'X-CSRF-TOKEN': window.csrfToken
        }
    })
    .then(response => response.json())
    .then(data => {
        if (!data.success) {
            throw new Error('Error al obtener los usuarios del examen');
        }

        const modalContent = document.getElementById('examenUsuariosModalContent');
        modalContent.innerHTML = `
            <ul class="list-group">
                ${data.usuarios.map(usuario => `
                    <li class="list-group-item">
                        <strong>Alumno:</strong> ${usuario.NombreUsuario}<br>
                        <strong>Estado:</strong> ${usuario.Estado}<br>
                        <strong>Calificación:</strong> ${usuario.Calificacion || 'N/A'}
                    </li>
                `).join('')}
            </ul>
        `;

        $('#examenUsuariosModal').modal('show');
    })
    .catch(error => {
        console.error(error.message);
        Swal.fire('Hubo un error al obtener los usuarios del examen. Por favor, inténtalo de nuevo.');
    });
}
