document.addEventListener('DOMContentLoaded', function() {
    const examDuration = window.examDuration; 
    const startTime = new Date(window.examStartTime).getTime();
    const endTime = startTime + examDuration * 60 * 1000;
    let isFormSubmitted = false;

    function updateTimer() {
        const now = new Date().getTime();
        const distance = endTime - now;

        const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
        const seconds = Math.floor((distance % (1000 * 60)) / 1000);

        document.getElementById('time-remaining').innerHTML = minutes + "m " + seconds + "s ";

        if (distance < 0) {
            clearInterval(timerInterval);
            document.getElementById('time-remaining').innerHTML = "Tiempo finalizado";
            document.getElementById('responder-examen-form').querySelectorAll('input, button').forEach(element => {
                element.disabled = true;
            });

            Swal.fire({
                icon: 'warning',
                title: 'Tiempo finalizado',
                text: 'El tiempo para completar el examen ha terminado.',
                showConfirmButton: true
            }).then(() => {
                completarExamen();
            });
        }
    }

    const timerInterval = setInterval(updateTimer, 1000);

    function completarExamen() {
        fetch(`${window.baseUrl}/misexamenes/completarExamen/${window.examenUsuarioId}`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-Requested-With': 'XMLHttpRequest',
                'X-CSRF-TOKEN': window.csrfToken
            }
        })
        .then(response => {
            if (!response.ok) {
                throw new Error('Error al completar el examen');
            }
            return response.json();
        })
        .then(data => {
            if (data.status !== 'success') {
                console.error('Error al completar el examen:', data.message);
            }
        })
        .catch(error => {
            console.error('Error:', error);
        });
    }

    function handleBeforeUnload(event) {
        if (!isFormSubmitted) {
            const confirmationMessage = "Recuerda que una vez que salgas tu examen se dará por terminado y tus respuestas no serán enviadas ni guardadas. ¿Estás seguro de que quieres salir?";
            event.returnValue = confirmationMessage; // Estándar moderno
            return confirmationMessage; // Compatibilidad con navegadores antiguos
        }
    }

    window.addEventListener('beforeunload', handleBeforeUnload);
    window.addEventListener('unload', function() {
        if (!isFormSubmitted) {
            completarExamen();
        }
    });

    document.getElementById('responder-examen-form').addEventListener('submit', function(event) {
        event.preventDefault();

        const submitButton = document.querySelector('.submit-quiz');
        submitButton.disabled = true;

        const formData = new FormData(this);
        const data = {};
        formData.forEach((value, key) => {
            if (key.includes('respuestas')) {
                const preguntaId = key.match(/\d+/)[0];
                if (!data['respuestas']) data['respuestas'] = {};
                data['respuestas'][preguntaId] = value;
            } else {
                data[key] = value;
            }
        });

        isFormSubmitted = true;

        fetch(window.baseUrl + 'misexamenes/guardarRespuestas', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-Requested-With': 'XMLHttpRequest',
                'X-CSRF-TOKEN': window.csrfToken
            },
            body: JSON.stringify(data)
        })
        .then(response => {
            if (!response.ok) {
                throw new Error('Error en la respuesta del servidor');
            }
            return response.json();
        })
        .then(data => {
            if (data.status === 'success') {
                Swal.fire({
                    icon: 'success',
                    title: 'Respuestas enviadas',
                    text: 'Tus respuestas se han guardado correctamente.',
                    showConfirmButton: false,
                    timer: 2000
                }).then(() => {
                    window.removeEventListener('beforeunload', handleBeforeUnload);
                    window.location.href = window.baseUrl + 'dashboard';
                });
            } else {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: data.message || 'Hubo un problema al guardar tus respuestas. Inténtalo nuevamente.',
                    showConfirmButton: false,
                    timer: 2000
                });
                submitButton.disabled = false;
                isFormSubmitted = false;
            }
        })
        .catch(error => {
            console.error('Error:', error);
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Hubo un problema al guardar tus respuestas. Inténtalo nuevamente.',
                showConfirmButton: false,
                timer: 2000
            });
            submitButton.disabled = false; 
            isFormSubmitted = false;
        });
    });
});
