document.addEventListener('DOMContentLoaded', function() {
  const joinCourseForm = document.getElementById('joinCourseForm');
  const tasksList = document.getElementById('tasksList');
  if (joinCourseForm) {
      joinCourseForm.addEventListener('submit', function(e) {
          e.preventDefault();
          const courseCode = document.getElementById('courseCode').value;
          console.log('Código del curso:', courseCode);

          fetch(baseUrl + '/dashboard/joinCourse', {
              method: 'POST',
              headers: {
                  'Content-Type': 'application/json'
              },
              body: JSON.stringify({ courseCode: courseCode })
          })
          .then(response => response.json())
          .then(data => {
              console.log('Respuesta del servidor:', data); // Añadir un log para verificar la respuesta
              if (data.status === 'success') {
                  Swal.fire({
                      title: 'Éxito',
                      text: data.message,
                      type: 'success',
                      confirmButtonText: 'OK'
                  }).then(() => {
                      location.reload();
                  });
              } else {
                  Swal.fire({
                      title: 'Error',
                      text: data.message,
                      type: 'error',
                      confirmButtonText: 'OK'
                  });
              }
          })
          .catch(error => {
              Swal.fire({
                  title: 'Error',
                  text: 'Ocurrió un error en el servidor. Por favor, inténtalo de nuevo más tarde.',
                  type: 'error',
                  confirmButtonText: 'OK'
              });
              console.error('Error:', error);
          });
      });
  }
  let isExpanded = false;

function loadMaterias(url) {
    fetch(url)
        .then(response => response.json())
        .then(data => {
            const maxVisibleItems = 8;
            tasksList.innerHTML = ''; // Limpia cualquier materia previa
            let visibleItems = data.slice(0, maxVisibleItems);
            let hiddenItems = data.slice(maxVisibleItems);

            visibleItems.forEach(materia => {
                const listItem = createMateriaItem(materia);
                tasksList.appendChild(listItem);
            });

            const viewMoreItem = document.createElement('a');
            viewMoreItem.href = '#';
            viewMoreItem.className = 'dropdown-item';
            viewMoreItem.style.borderTop = '1px solid #5CACFB'; // Añadir una separación visual
            viewMoreItem.style.marginTop = '10px';
            updateViewMoreText(viewMoreItem);

            viewMoreItem.addEventListener('click', function (event) {
                event.preventDefault();
                if (isExpanded) {
                    hiddenItems.forEach(() => tasksList.removeChild(tasksList.children[maxVisibleItems]));
                    isExpanded = false;
                } else {
                    hiddenItems.forEach(materia => {
                        const listItem = createMateriaItem(materia);
                        tasksList.insertBefore(listItem, viewMoreItem);
                    });
                    isExpanded = true;
                }
                updateViewMoreText(viewMoreItem);
            });

            tasksList.appendChild(viewMoreItem);

            // Agregar ítem para "Unirme a materia"
            const joinCourseItem = document.createElement('a');
            joinCourseItem.href = '#';
            joinCourseItem.className = 'dropdown-item';
            joinCourseItem.style.marginTop = '10px';
            joinCourseItem.setAttribute('data-toggle', 'modal');
            joinCourseItem.setAttribute('data-target', '#addCourseModal');
            joinCourseItem.innerHTML = `<i class="material-icons">add</i> Unirme a materia`;
            joinCourseItem.addEventListener('click', function (event) {
                // Previene el comportamiento por defecto si es necesario
                event.preventDefault();
                // Abre el modal manualmente
                $('#addCourseModal').modal('show');
            });
            tasksList.appendChild(joinCourseItem);
        })
        .catch(error => console.error('Error al cargar las materias:', error));
}
function getIconForMateria(materiaName) {
  const iconMapping = {
      'Pensamiento Matemático I': 'calculate',
      'Humanidades': 'people',
      'Ciencias Sociales I': 'public',
      'Inglés I': 'language',
      'La materia y sus interacciones': 'science',
      'Cultura Digital': 'computer',
      'Lengua y Comunicación': 'menu_book',
      'Laboratorio de investigación': 'biotech',
      // Agrega más mapeos según las materias que tengas
  };

  return iconMapping[materiaName] || 'school'; // Default icon
}


function createMateriaItem(materia) {
  const listItem = document.createElement('div');
  listItem.className = 'dropdown-item';
  listItem.style.display = 'grid';
  listItem.style.gridTemplateColumns = '1fr 50px';
  listItem.style.alignItems = 'center';

  const icon = getIconForMateria(materia.MateriaName);

  const materiaLink = document.createElement('a');
  materiaLink.href = baseUrl + '/materia/' + materia.FK_Materia;
  materiaLink.style.textDecoration = 'none';
  materiaLink.style.color = '#ffffff';
  materiaLink.innerHTML = `<i class="material-icons">${icon}</i> <span>${materia.MateriaName}</span>`;

  const linkIcon = document.createElement('a');
  linkIcon.href = materia.Meet ? materia.Meet : '#';
  linkIcon.target = "_blank";
  linkIcon.innerHTML = `<i class="material-icons route-icon">link</i>`;
  linkIcon.addEventListener('click', function (event) {
      if (!materia.Meet) {
          event.preventDefault();
          showAlertNoLink();
      }
  });

  listItem.appendChild(materiaLink);
  listItem.appendChild(linkIcon);
  return listItem;
}


function showAlertNoLink() {
  Swal.fire({
      icon: 'info',
      title: 'Enlace no disponible',
      text: 'Aún no han cargado el enlace de Meet de la materia.',
      confirmButtonText: 'Entendido'
  });
}


function updateViewMoreText(viewMoreItem) {
    viewMoreItem.innerHTML = isExpanded ? `<i class="material-icons">expand_less</i> Ver menos` : `<i class="material-icons">expand_more</i> Ver más`;
}

// Inicializar la carga de materias según el rol
if (userRole == 3) {
    loadMaterias(baseUrl + '/dashboard/getMateriasMaestroEspecial');
} else {
    loadMaterias(baseUrl + '/dashboard/getMaterias');
}

// Evitar que el dropdown se cierre al hacer clic en "Ver más"
document.querySelector('#tasksMenu').addEventListener('click', function (event) {
    event.stopPropagation();
});

// Cierra cualquier dropdown abierto cuando se abre otro
$('.navbar-nav .dropdown').on('show.bs.dropdown', function () {
    $('.navbar-nav .dropdown').not(this).find('.dropdown-menu').removeClass('show');
});



    // Obtener avisos
    fetch(baseUrl + '/MisAvisos/obtenerUltimosAvisos')
        .then(response => response.json())
        .then(data => {
            const notificationMenu = document.getElementById('notificationMenu');
            notificationMenu.innerHTML = '';
            data.forEach(aviso => {
                const avisoElement = document.createElement('a');
                avisoElement.classList.add('dropdown-item');
                avisoElement.href = baseUrl + '/MisAvisos';
                avisoElement.textContent = aviso.Titulo;
                notificationMenu.appendChild(avisoElement);
            });

            if (data.length === 0) {
                const noAvisosElement = document.createElement('a');
                noAvisosElement.classList.add('dropdown-item');
                noAvisosElement.textContent = 'No hay avisos recientes';
                notificationMenu.appendChild(noAvisosElement);
            }
        })
        .catch(error => console.error('Error al obtener los avisos:', error));

    fetch(baseUrl + '/MisAvisos/obtenerCantidadAvisos')
        .then(response => response.json())
        .then(data => {
            const notificationCount = document.getElementById('notificationCount');
            notificationCount.textContent = data.cantidad;
        })
        .catch(error => console.error('Error al obtener la cantidad de avisos:', error));
});


