document.addEventListener('DOMContentLoaded', function () {
   
     // Escuchar el formulario de subida
     document.getElementById('uploadMaterialForm').addEventListener('submit', function(e) {
        e.preventDefault();
        uploadMaterial(); // Llamamos a la función para manejar la subida
    });

    const fileInput = document.getElementById('Archivo');
    const filePreview = document.getElementById('filePreview');
    const removeFileButton = document.getElementById('removeFileButton');

    fileInput.addEventListener('change', function() {
        const file = this.files[0];
        const allowedExtensions = ['pdf', 'docx', 'jpg', 'jpeg', 'png']; // Tipos de archivo permitidos
        const maxSizeMB = 50; // Tamaño máximo permitido (50MB)
        const fileExtension = file.name.split('.').pop().toLowerCase();

        // Limpiar previsualización previa
        filePreview.innerHTML = ''; 

        // Verificar el tipo de archivo
        if (!allowedExtensions.includes(fileExtension)) {
            Swal.fire({
                type: 'error',
                title: 'Formato no permitido',
                text: 'Solo se permiten archivos PDF, DOCX, JPG y PNG.'
            });
            this.value = ''; // Limpiar input
            return;
        }

        // Verificar el tamaño del archivo
        if (file.size > maxSizeMB * 1024 * 1024) {
            Swal.fire({
                type: 'error',
                title: 'Archivo demasiado grande',
                text: `El tamaño máximo permitido es de ${maxSizeMB}MB.`
            });
            this.value = ''; // Limpiar input
            return;
        }

        // Previsualizar el archivo si es permitido
        const reader = new FileReader();
        reader.onload = function(e) {
            if (file.type.startsWith('image/')) {
                filePreview.innerHTML = `<img src="${e.target.result}" alt="Vista previa del archivo">`;
            } else if (file.type === 'application/pdf') {
                filePreview.innerHTML = `<iframe src="${e.target.result}" style="width: 100%; height: 400px;"></iframe>`;
            } else {
                filePreview.innerHTML = `<p>Archivo seleccionado: ${file.name}</p>`;
            }
        };
        reader.readAsDataURL(file);
        removeFileButton.style.display = 'inline-block'; // Mostrar botón para remover archivo
    });
    
    // Eliminar archivo seleccionado
    removeFileButton.addEventListener('click', function() {
        removeFile();
    });

   
    // Obtener las variables desde el contexto global
    const materiaId = window.materiaId;
    const baseUrl = window.baseUrl;
    const userRole = window.userRole;
    const userId = window.userId;

    // Fetch para obtener los grupos
    fetch(baseUrl + 'get_groups')
        .then(response => response.json())
        .then(data => {
            const groupSelect = document.getElementById('groupId');
            data.forEach(group => {
                const option = document.createElement('option');
                option.value = group.PK_Group;
                option.textContent = group.GroupName;
                groupSelect.appendChild(option);
            });
        });

    // Fetch para obtener el código de la clase de la materia
    fetch(baseUrl + 'materia/getCodeClass', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ materiaId: materiaId })
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            const codeClass = data.codeClass;
            document.getElementById('codeClassTitle').innerText = `Código: ${codeClass}`;
        } else {
            console.error('Error fetching code class:', data.message);
        }
    })
    .catch(error => {
        console.error('Error:', error);
    });



    // Fetch para obtener el código de la clase de la materia
    fetch(baseUrl + 'materia/getMeetClass', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ materiaId: materiaId })
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            const MeetClass = data.meet;
            const meetLink = document.getElementById('Meet');
            meetLink.href = MeetClass;
        } else {
            console.error('Error fetching code class:', data.message);
        }
    })
    .catch(error => {
        console.error('Error:', error);
    });
});





function setMateriaId(materiaId) {
    document.getElementById('materiaId').value = materiaId;
}

function setMateriaSession(pkMateria) {
    fetch(baseUrl + 'materia/setSessionMateria', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ pkMateria: pkMateria })
    });
}

document.getElementById('saveTaskButton').addEventListener('click', function () {
    var form = document.getElementById('createTaskForm');
    var formData = new FormData(form);

    fetch(baseUrl + 'crear_tarea', {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(data => {
        if (data.status === 'success') {
            Swal.fire({
                type: 'success',
                title: 'Tarea creada',
                text: 'La tarea se ha creado exitosamente',
                showConfirmButton: false,
                timer: 1500
            }).then(() => {
                $('#createTaskModal').modal('hide');
                form.reset();
                location.reload();
            });
        } else if (data.errors) {
            let errorMessages = '';
            for (const [key, value] of Object.entries(data.errors)) {
                errorMessages += `${value}\n`;
            }
            Swal.fire({
                type: 'error',
                title: 'Error de validación',
                text: errorMessages
            });
        } else {
            Swal.fire({
                type: 'error',
                title: 'Error',
                text: 'No se pudo crear la tarea'
            });
        }
    })
    .catch(error => {
        Swal.fire({
            type: 'error',
            title: 'Error',
            text: 'Hubo un problema con el servidor'
        });
    });
});

function copyCodeToClipboard() {
    const codeClass = document.getElementById('codeClassTitle').innerText.replace('Código: ', '');
    navigator.clipboard.writeText(codeClass).then(function() {
        Swal.fire({
            type: 'success',
            title: 'Código copiado',
            text: 'El código de la materia ha sido copiado al portapapeles.',
            showConfirmButton: false,
            timer: 1500
        });
    }, function(err) {
        Swal.fire({
            type: 'error',
            title: 'Error',
            text: 'Hubo un problema al copiar el código.',
        });
        console.error('Error copying text: ', err);
    });
}
let currentPage = 1;
const itemsPerPage = 5;
let allCalificaciones = [];

document.addEventListener('DOMContentLoaded', function() {

    document.getElementById('uploadMaterialForm').addEventListener('submit', function(e) {
        e.preventDefault();
        uploadMaterial();
    });

    $('#uploadMaterialModal').on('hidden.bs.modal', function () {
        document.getElementById('uploadMaterialForm').reset();
    });

    const fileInput = document.getElementById('Archivo');
    const filePreview = document.getElementById('filePreview');
    const removeFileButton = document.getElementById('removeFileButton');

    fileInput.addEventListener('change', function() {
        const file = this.files[0];
        filePreview.innerHTML = ''; 

        if (file) {
            const reader = new FileReader();
            reader.onload = function(e) {
                if (file.type.startsWith('image/')) {
                    filePreview.innerHTML = `<img src="${e.target.result}" alt="Vista previa del archivo">`;
                } else if (file.type === 'application/pdf') {
                    filePreview.innerHTML = `<iframe src="${e.target.result}" style="width: 100%; height: 400px;"></iframe>`;
                } else {
                    filePreview.innerHTML = `<p>Archivo seleccionado: ${file.name}</p>`;
                }
            };
            reader.readAsDataURL(file);
            removeFileButton.style.display = 'inline-block'; 
        }
    });

    $('#calificacionesModal').on('show.bs.modal', function () {
        $.post(getCalificacionesUrl, { materiaId: materiaId, userId: userId }, function(data) {
            if (data.length > 0) {
                allCalificaciones = data;
                renderCalificaciones(data, currentPage);
                renderPagination(data.length, currentPage);
                updatePromedio(data);
            } else {
                $('#calificaciones-content').html('<tr><td colspan="3">No se encontraron calificaciones.</td></tr>');
                $('#promedio-calificaciones').text('Promedio: N/A');
                $('#pagination-calificaciones').html('');
            }
        });
    });
});

function setMateriaSession(pkMateria) {
    fetch(setSessionMateriaUrl, {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ pkMateria: pkMateria })
    });
}
// Función para subir el material con validación
function uploadMaterial() {
    const form = document.getElementById('uploadMaterialForm');
    const formData = new FormData(form);

    // Deshabilitar el botón de enviar para evitar duplicación
    const submitButton = document.querySelector('#uploadMaterialForm button[type="submit"]');
    
    // Si el botón ya está deshabilitado, retornamos para evitar doble envío
    if (submitButton.disabled) return;

    // Deshabilitar el botón para prevenir múltiples envíos
    submitButton.disabled = true;

    // Mostrar pantalla de carga
    Swal.fire({
        type: 'info',
        title: 'Subiendo...',
        html: 'Por favor espera mientras subimos tu archivo.',
        allowOutsideClick: false,
        didOpen: () => {
            Swal.showLoading(); // Mostrar spinner de carga
        }
    });

    fetch(uploadMaterialUrl, {
        method: 'POST',
        body: formData
    })
    .then(response => response.json())
    .then(data => {
        // Cerrar la pantalla de carga después de un pequeño retraso
        setTimeout(() => {
            Swal.close();
            submitButton.disabled = false; // Habilitar el botón nuevamente

            if (data.success) {
                Swal.fire({
                    type: 'success',
                    title: 'Material subido',
                    text: 'El material se ha subido exitosamente.',
                    showConfirmButton: true,  // Mostrar botón de cerrar
                    timer: 5000  // Mantener visible por 3 segundos antes de cerrar
                }).then(() => {
                    $('#uploadMaterialModal').modal('hide');
                    document.getElementById('uploadMaterialForm').reset(); // Limpiar formulario
                    location.reload(); // Refrescar la página
                });
            } else {
                Swal.fire({
                    type: 'error',
                    title: 'Error',
                    text: 'Hubo un problema al subir el material.'
                });
            }
        }, 1000);  // Pausa de 1 segundo antes de cerrar la pantalla de carga

    })
    .catch(error => {
        // Manejo del error, habilitar el botón nuevamente
        Swal.close();
        submitButton.disabled = false;
        console.error('Error:', error);
        Swal.fire({
            type: 'error',
            title: 'Error',
            text: 'Hubo un problema al subir el material.',
        });
    });
}

// Escuchar el evento del formulario
document.getElementById('uploadMaterialForm').addEventListener('submit', function(e) {
    e.preventDefault();
    uploadMaterial(); // Llamamos a la función para manejar la subida
});



function viewMaterial(file) {
    const extension = file.split('.').pop().toLowerCase();
    const fileUrl = uploadPath + file;
    let content;

    if (['jpg', 'jpeg', 'png', 'gif'].includes(extension)) {
        content = `<img src="${fileUrl}" class="img-fluid" alt="Archivo">`;
    } else if (['pdf'].includes(extension)) {
        content = `<iframe src="${fileUrl}" style="width: 100%; height: 500px;" frameborder="0"></iframe>`;
    } else {
        content = `<p>No se puede previsualizar este tipo de archivo. <a href="${fileUrl}" target="_blank">Descargar</a></p>`;
    }

    Swal.fire({
        html: content,
        width: 800,
        showCloseButton: true,
        showConfirmButton: false,
    });
}

function removeFile() {
    const fileInput = document.getElementById('Archivo');
    const filePreview = document.getElementById('filePreview');
    const removeFileButton = document.getElementById('removeFileButton');

    fileInput.value = ''; 
    filePreview.innerHTML = ''; 
    removeFileButton.style.display = 'none'; 
}

function renderCalificaciones(calificaciones, page) {
    const start = (page - 1) * itemsPerPage;
    const end = start + itemsPerPage;
    const paginatedCalificaciones = calificaciones.slice(start, end);

    let content = '';
    paginatedCalificaciones.forEach(function(calificacion) {
        let estado = calificacion.Calificacion >= 6 ? 'Aprobada' : 'No aprobatoria';
        content += `<tr><td>${calificacion.NombreTarea}</td><td>${calificacion.Calificacion}</td><td>${estado}</td></tr>`;
    });
    $('#calificaciones-content').html(content);
}

function renderPagination(totalItems, currentPage) {
    const totalPages = Math.ceil(totalItems / itemsPerPage);
    const pagination = $('#pagination-calificaciones');
    pagination.html('');

    for (let i = 1; i <= totalPages; i++) {
        const li = $('<li>', { class: `page-item ${i === currentPage ? 'active' : ''}` });
        const a = $('<a>', { class: 'page-link', href: '#', text: i, click: function (e) {
            e.preventDefault();
            loadPage(i);
        }});
        li.append(a);
        pagination.append(li);
    }
}

function loadPage(page) {
    currentPage = page;
    renderCalificaciones(allCalificaciones, page);
    renderPagination(allCalificaciones.length, page);
}

function updatePromedio(calificaciones) {
    const totalCalificaciones = calificaciones.reduce((sum, calificacion) => sum + parseFloat(calificacion.Calificacion), 0);
    const promedio = (totalCalificaciones / calificaciones.length).toFixed(2);
    $('#promedio-calificaciones').text(`Promedio: ${promedio}`);
}
