// Definir todas las funciones fuera del bloque condicional

// Obtener elementos del DOM
var modal;
var span;

// Cerrar el modal al hacer clic en la "x"
function closeModal() {
    modal.style.display = "none";
}

// Cerrar el modal al hacer clic fuera de él
function outsideClick(event) {
    if (event.target == modal) {
        modal.style.display = "none";
    }
}
// Manejar el envío del formulario de subida de archivos
function handleUploadFormSubmit(event) {
    event.preventDefault();
    try {
        var formData = new FormData(this);
        var submitButton = this.querySelector('button[type="submit"]');
        var fileInput = this.querySelector('input[type="file"]');
        var file = fileInput.files[0];

        // Verificar si se seleccionó un archivo
        if (!file) {
            Swal.fire({
                icon: 'warning',
                title: 'Archivo no seleccionado',
                text: 'Por favor selecciona un archivo para subir.',
            });
            return;
        }

        // Verificar si el archivo tiene un tipo permitido
        var allowedTypes = [
            'application/vnd.openxmlformats-officedocument.wordprocessingml.document', // docx
            'application/pdf', // pdf
            'image/jpeg', // jpg, jpeg
            'image/png', // png
            'image/gif' // gif
        ];

        if (!allowedTypes.includes(file.type)) {
            Swal.fire({
                icon: 'error',
                title: 'Tipo de archivo no permitido',
                text: 'Solo se permiten archivos de tipo .docx, .pdf, .jpg, .jpeg, .png, .gif.',
            });
            return;
        }

        // Validación de tamaño para archivos .docx y .pdf (máximo 5MB)
        if (['application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'application/pdf'].includes(file.type)) {
            if (file.size > 5 * 1024 * 1024) { // 5 MB
                Swal.fire({
                    icon: 'error',
                    title: 'Archivo demasiado grande',
                    text: 'El archivo seleccionado es demasiado grande. El tamaño máximo permitido es de 5 MB.',
                });
                return;
            }
        }

        // Reducción de tamaño para imágenes (máximo 800px de ancho/alto)
        if (file.type.startsWith('image/')) {
            var reader = new FileReader();
            reader.onload = function(event) {
                var img = new Image();
                img.src = event.target.result;

                img.onload = function() {
                    var canvas = document.createElement('canvas');
                    var maxWidth = 800;
                    var maxHeight = 800;
                    var width = img.width;
                    var height = img.height;

                    // Calcular las nuevas dimensiones
                    if (width > height) {
                        if (width > maxWidth) {
                            height *= maxWidth / width;
                            width = maxWidth;
                        }
                    } else {
                        if (height > maxHeight) {
                            width *= maxHeight / height;
                            height = maxHeight;
                        }
                    }

                    canvas.width = width;
                    canvas.height = height;

                    var ctx = canvas.getContext('2d');
                    ctx.drawImage(img, 0, 0, width, height);

                    // Convertir el canvas a Blob
                    canvas.toBlob(function(blob) {
                        formData.set('file', blob, file.name); // Reemplaza el archivo original en el FormData
                        submitFormData(formData, submitButton); // Llamar a la función para enviar el archivo
                    }, file.type);
                };
            };
            reader.readAsDataURL(file);
        } else {
            // Para archivos que no son imágenes
            submitFormData(formData, submitButton);
        }

    } catch (error) {
        Swal.fire({
            icon: 'error',
            title: 'Error inesperado',
            text: 'Ocurrió un error inesperado al intentar subir el archivo.',
        });
        console.error('Error:', error); // Puedes eliminar esta línea si no quieres ningún log en consola
    }
}

// Enviar la solicitud de subida del archivo
function submitFormData(formData, submitButton) {
    submitButton.disabled = true;
    submitButton.innerText = "Subiendo...";

    var xhr = new XMLHttpRequest();

    xhr.upload.onprogress = function(event) {
        if (event.lengthComputable) {
            var percentComplete = (event.loaded / event.total) * 100;
            Swal.fire({
                title: 'Subiendo archivo...',
                html: `<progress value="${percentComplete}" max="100"></progress>`,
                timerProgressBar: true,
                allowOutsideClick: false,
                showConfirmButton: false,
                didOpen: () => {
                    Swal.showLoading();
                }
            });
        }
    };

    xhr.onload = function() {
        if (xhr.status === 200) {
            var response = JSON.parse(xhr.responseText);
            if (response.success) {
                setTimeout(() => {
                    Swal.fire({
                        icon: 'success',
                        title: 'Éxito',
                        text: response.message,
                    }).then(() => {
                        modal.style.display = "none";
                        submitButton.disabled = false;
                        submitButton.innerText = "Subir";
                        document.getElementById('uploadedFileInfo').innerHTML = ''; // Refresca la info de archivo subido
                    });
                }, 500); // Retraso de 500 ms antes de mostrar la alerta de éxito
            } else {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: response.message,
                });
                submitButton.disabled = false;
                submitButton.innerText = "Subir";
            }
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Error en la respuesta del servidor.',
            });
            submitButton.disabled = false;
            submitButton.innerText = "Subir";
        }
    };

    xhr.onerror = function() {
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: 'Error de conexión durante la carga del archivo.',
        });
        submitButton.disabled = false;
        submitButton.innerText = "Subir";
    };

    var form = document.getElementById('uploadForm');
    var url = form.getAttribute('data-url');
    
    xhr.open('POST', url, true);
    
    xhr.send(formData);
}


function deleteFile(tareaId, archivo) {
    fetch(baseUrl + 'tareas/eliminarArchivo', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ tarea_id: tareaId, archivo: archivo }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            Swal.fire({
                icon: 'success',
                title: 'Éxito',
                text: data.message,
            }).then(() => {
                document.getElementById('uploadedFileInfo').innerHTML = '';
            });
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: data.message,
            });
        }
    })
    .catch(error => {
        console.error('Error:', error);
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: 'Error al eliminar la referencia del archivo en la base de datos.',
        });
    });
}

// Abrir el modal y cargar detalles de la tarea
function openModal(tareaId) {
    fetch(baseUrl + 'mistareas/obtenerDetalleTarea/' + tareaId)
        .then(response => response.json())
        .then(data => {
            if (data.error) {
                Swal.fire({
                    icon: 'error',
                    title: 'Error',
                    text: data.error,
                });
                return;
            }

            document.getElementById('nombreTarea').innerText = data.NombreTarea || 'N/A';
            document.getElementById('nombreMateria').innerText = data.NombreMateria || 'N/A';
            document.getElementById('fechaEntrega').innerText = data.FechaEntrega || 'N/A';
            document.getElementById('descripcionTarea').innerText = data.DescripcionTarea || 'N/A';
            document.getElementById('calificacion').innerText = data.Calificacion || 'N/A';
            document.getElementById('comentarios').innerText = data.Comentarios || 'N/A';
            document.getElementById('tareaId').value = data.PK_TareaUsuario;

            var uploadedFileInfo = document.getElementById('uploadedFileInfo');
            if (data.Archivo) {
                uploadedFileInfo.innerHTML = `
                    <p><strong>Archivo Subido:</strong> <a href="${baseUrl}uploads/${data.Archivo}" target="_blank">${data.Archivo}</a></p>
                    <i class="material-icons">attach_file</i> <!-- Ícono representativo -->
                    <button id="deleteFileBtn" data-file="${data.Archivo}" class="btn-delete">Eliminar Archivo</button>
                `;
                document.getElementById('deleteFileBtn').onclick = function() {
                    deleteFile(tareaId, data.Archivo);
                };
            } else {
                uploadedFileInfo.innerHTML = '';
            }

            var uploadSection = document.getElementById('uploadSection');

            // Mostrar la sección de subida solo si el estado es "Pendiente"
            if (data.EstadoTarea === 'Pendiente') {
                uploadSection.style.display = 'block';
            } else {
                uploadSection.style.display = 'none';
            }

            modal.style.display = "block";
        })
        .catch(error => {
            console.error('Error:', error);
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: 'Error al obtener los detalles de la tarea.',
            });
        });
}



// Obtener tareas completadas
function fetchTareasCompletadas(pkMateria) {
    fetch(baseUrl + 'mistareas/obtenerTareas/' + pkMateria)
        .then(response => response.json())
        .then(data => {
            var tareasListEntregadas = document.getElementById('tareas-list-entregadas');
            tareasListEntregadas.innerHTML = '';
            data.forEach(function(tarea) {
                var listItem = document.createElement('li');
                listItem.className = 'ux-regCard';
                
                var calificacionClass = tarea.Calificacion > 6 ? 'green-text' : 'red-text';

                listItem.innerHTML = `
                    <div class="ux-wrapper-draftContent">
                        <div class="ux-wrapper-draftInfo">
                            <div class="ux-regCard-title">
                                <span>${tarea.NombreTarea}</span>
                            </div>
                            <div class="ux-regCard-content">
                                <span class="ux-dataHeader" style="font-size: 12px;">Fecha límite de entrega: ${tarea.FechaEntrega}</span>
                                <br>
                                <span style="font-size: 12px;">Descripción: ${tarea.DescripcionTarea}</span>
                                <br>
                                <span class="${calificacionClass}" style="font-size: 12px;">Calificación: ${tarea.Calificacion}</span>
                            </div>
                        </div>
                    </div>
                    <div class="ux-container-order-cell">
                        <div class="ux-row-order-header ux-row-links">
                            <button class="btn-rose btn" onclick="openModal(${tarea.PK_TareaUsuario})">Ver</button>
                        </div>
                    </div>
                `;
                tareasListEntregadas.appendChild(listItem);
            });
        })
        .catch(error => {
            console.error('Error:', error);
        });
}

// Obtener tareas pendientes
function fetchTareasPendientes(pkMateria) {
    fetch(baseUrl + 'mistareas/obtenerTareasPendientes/' + pkMateria)
        .then(response => response.json())
        .then(data => {
            var tareasListPendientes = document.getElementById('tareas-list-pendientes');
            tareasListPendientes.innerHTML = '';
            data.forEach(function(tarea) {
                var listItem = document.createElement('li');
                listItem.className = 'ux-regCard';

                var calificacionClass = tarea.Calificacion > 6 ? 'green-text' : 'red-text';

                // Formato de la fecha de entrega
                var fechaEntrega = new Date(tarea.FechaEntrega);
                var hoy = new Date();

                // Extraer solo la parte de la fecha (día, mes, año) y compararlas
                var fechaEntregaDateOnly = fechaEntrega.toISOString().split('T')[0];
                var hoyDateOnly = hoy.toISOString().split('T')[0];

            

                // Comparar solo las fechas
                var tareaAtrasada = hoyDateOnly > fechaEntregaDateOnly ? '<span class="overdue"> (Tarea atrasada)</span>' : '';

                listItem.innerHTML = `
                    <div class="ux-wrapper-draftContent">
                        <div class="ux-wrapper-draftInfo">
                            <div class="ux-regCard-title">
                                <span>${tarea.NombreTarea}${tareaAtrasada}</span>
                            </div>
                            <div class="ux-regCard-content">
                                <span class="ux-dataHeader" style="font-size: 12px;">Fecha límite de entrega: ${fechaEntregaDateOnly}</span>
                                <br>
                                <span style="font-size: 12px;">Descripción: ${tarea.DescripcionTarea}</span>
                                <br>
                                <span class="${calificacionClass}" style="font-size: 12px;">Calificación: ${tarea.Calificacion}</span>
                            </div>
                        </div>
                    </div>
                    <div class="ux-container-order-cell">
                        <div class="ux-row-order-header ux-row-links">
                            <button class="btn-rose btn" onclick="openModal(${tarea.PK_TareaUsuario})">Ver</button>
                            <button class="btn-rose btn" onclick="submitTarea(${tarea.PK_TareaUsuario})">Entregar</button>
                        </div>
                    </div>
                `;
                tareasListPendientes.appendChild(listItem);
            });
        })
        .catch(error => {
            console.error('Error:', error);
        });
}

// Enviar una tarea
function submitTarea(tareaId) {
    const now = new Date().toISOString().slice(0, 19).replace('T', ' '); // Formato YYYY-MM-DD HH:MM:SS

    fetch(baseUrl + 'mistareas/actualizarEstado', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({
            PK_TareaUsuario: tareaId,
            Estado: 'Completada',
            FechaTareaRecibida: now
        }),
    })
    .then(response => response.json())
    .then(data => {
        if (data.success) {
            Swal.fire({
                icon: 'success',
                title: 'Tarea subida',
                text: 'Tarea subida y entregada.',
            }).then(() => {
                fetchTareasPendientes(pkMateria);
                location.reload(); 
            });
        } else {
            Swal.fire({
                icon: 'error',
                title: 'Error',
                text: data.message,
            });
        }
    })
    .catch(error => {
        console.error('Error:', error);
        Swal.fire({
            icon: 'error',
            title: 'Error',
            text: 'Hubo un problema al subir la tarea.',
        });
    });
}

// Obtener tareas calificadas
function fetchTareasCalificadas(pkMateria) {
    fetch(baseUrl + 'mistareas/obtenerTareasCalificadas/' + pkMateria)
        .then(response => response.json())
        .then(data => {
            var tareasListCalificadas = document.getElementById('tareas-list-calificadas');
            tareasListCalificadas.innerHTML = '';
            data.forEach(function(tarea) {
                var listItem = document.createElement('li');
                listItem.className = 'ux-regCard';
                
                var calificacionClass = tarea.Calificacion > 6 ? 'green-text' : 'red-text';

                listItem.innerHTML = `
                    <div class="ux-wrapper-draftContent">
                        <div class="ux-wrapper-draftInfo">
                            <div class="ux-regCard-title">
                                <span>${tarea.NombreTarea}</span>
                            </div>
                            <div class="ux-regCard-content">
                                <span class="ux-dataHeader" style="font-size: 12px;">Fecha límite de entrega: ${tarea.FechaEntrega}</span>
                                <br>
                                <span style="font-size: 12px;">Descripción: ${tarea.DescripcionTarea}</span>
                                <br>
                                <span class="${calificacionClass}" style="font-size: 12px;">Calificación: ${tarea.Calificacion}</span>
                            </div>
                        </div>
                    </div>
                    <div class="ux-container-order-cell">
                        <div class="ux-row-order-header ux-row-links">
                            <button class="btn-rose btn" onclick="openModal(${tarea.PK_TareaUsuario})">Ver</button>
                        </div>
                    </div>
                `;
                tareasListCalificadas.appendChild(listItem);
            });
        })
        .catch(error => {
            console.error('Error:', error);
        });
}

// Actualizar la fecha en el documento
function updateDate() {
    const now = new Date();
    const options = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
    const formattedDate = now.toLocaleDateString('es-ES', options);
    document.querySelectorAll('.ux-event-date-orders span').forEach(span => {
        span.textContent = formattedDate;
    });
}

// Inicializar al cargar el documento
document.addEventListener('DOMContentLoaded', (event) => {
    const userType = window.userRole;

    if (userType == 4) {
        modal = document.getElementById("myModal");
        span = document.getElementsByClassName("close")[0];

        span.onclick = closeModal;
        window.onclick = outsideClick;
        document.getElementById('uploadForm').onsubmit = handleUploadFormSubmit;

        updateDate();
        fetchTareasCompletadas(pkMateria);
        fetchTareasPendientes(pkMateria);
        fetchTareasCalificadas(pkMateria);
        setInterval(updateDate, 1000 * 60 * 60 * 24); 
    }
});
