document.addEventListener('DOMContentLoaded', function () {
    const userType = window.userRole;
    const pkMateria = window.pkMateria;

    if (userType == 3) {
        fetchTareas(pkMateria, 1);

        document.getElementById('pagination').addEventListener('click', function (event) {
            if (event.target.tagName === 'A') {
                const page = event.target.getAttribute('data-page');
                fetchTareas(pkMateria, page);
            }
        });
    }

    function fetchTareas(pkMateria, page) {
        fetch(`${window.baseUrl}/mis_tareas/todasMisTareasMaestro/${pkMateria}/${page}`)
            .then(response => response.json())
            .then(data => {
                const tbody = document.getElementById('tareasAsignadasMaestro');
                if (!tbody) {
                    console.error('El elemento tbody con el ID "tareasAsignadasMaestro" no existe.');
                    return;
                }

                tbody.innerHTML = '';

                if (data.tareas.length > 0) {
                    data.tareas.forEach(function (tarea) {
                        const row = document.createElement('tr');
                        row.innerHTML = `
                            <td data-label="Título de la tarea">${tarea.Nombre}</td>
                            <td data-label="Descripción">${tarea.Descripción}</td>
                            <td data-label="Fecha de entrega">${tarea.FechaEntrega}</td>
                            <td data-label="Estado">${tarea.Estado}</td>
                            <td data-label="Acciones">
                                <button class="btn btn-primary btn-link btn-sm" onclick="window.location.href='${window.baseUrl}/mis_tareas/misTareasMaestro/${pkMateria}/${tarea.PK_Tarea}'">
                                    <i class="material-icons">edit</i>
                                </button>
                                <button class="btn btn-rose btn-link btn-sm" onclick="borrarTarea(${tarea.PK_Tarea})">
                                    <i class="material-icons">delete</i>
                                </button>
                            </td>
                        `;
                        tbody.appendChild(row);
                    });

                    renderPagination(data.total, data.perPage, data.currentPage);
                } else {
                    tbody.innerHTML = '<tr><td colspan="5">No se encontraron tareas asignadas.</td></tr>';
                }
            })
            .catch(error => {
                console.error('Error:', error);
                const tbody = document.getElementById('tareasAsignadasMaestro');
                if (tbody) {
                    tbody.innerHTML = '<tr><td colspan="5">Hubo un problema al cargar las tareas.</td></tr>';
                }
            });
    }

    function renderPagination(totalItems, itemsPerPage, currentPage) {
        const totalPages = Math.ceil(totalItems / itemsPerPage);
        const pagination = document.getElementById('pagination');
        if (!pagination) {
            console.error('El elemento con el ID "pagination" no existe.');
            return;
        }

        pagination.innerHTML = '';

        for (let i = 1; i <= totalPages; i++) {
            const li = document.createElement('li');
            li.className = 'page-item' + (i === parseInt(currentPage) ? ' active' : '');
            const a = document.createElement('a');
            a.className = 'page-link';
            a.href = '#';
            a.setAttribute('data-page', i);
            a.textContent = i;
            li.appendChild(a);
            pagination.appendChild(li);
        }
    }

    function borrarTarea(tareaId) {
        Swal.fire({
            title: '¿Estás seguro de que deseas borrar esta tarea?',
            text: "Esta acción no se puede deshacer.",
            icon: 'warning',
            showCancelButton: true,
            confirmButtonColor: '#3085d6',
            cancelButtonColor: '#d33',
            confirmButtonText: 'Sí, borrar',
            cancelButtonText: 'Cancelar'
        }).then((result) => {
            if (result.isConfirmed) {
                fetch(`${window.baseUrl}/mis_tareas/archivarTarea`, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({ PK_Tarea: tareaId })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.success) {
                        Swal.fire({
                            icon: 'success',
                            title: 'Tarea borrada',
                            text: 'La tarea ha sido borrada exitosamente.',
                            showConfirmButton: false,
                            timer: 1500
                        }).then(() => {
                            fetchTareas(window.pkMateria, 1);
                        });
                    } else {
                        Swal.fire({
                            icon: 'error',
                            title: 'Error',
                            text: 'Hubo un problema al borrar la tarea.'
                        });
                    }
                })
                .catch(error => {
                    console.error('Error:', error);
                    Swal.fire({
                        icon: 'error',
                        title: 'Error',
                        text: 'Hubo un problema al borrar la tarea.'
                    });
                });
            } else if (result.dismiss === Swal.DismissReason.cancel) {
                Swal.fire({
                    icon: 'error',
                    title: 'Cancelado',
                    text: 'La tarea no ha sido borrada.'
                });
            }
        });
    }

    // Expose functions to the global scope to be accessible by the HTML elements
    window.borrarTarea = borrarTarea;
});
