document.addEventListener('DOMContentLoaded', function() {
  // Enviar aviso
  const enviarAvisoForm = document.getElementById('enviarAvisoForm');
  if (enviarAvisoForm) {
      enviarAvisoForm.addEventListener('submit', function(e) {
          e.preventDefault();

          const formData = new FormData(this);

          fetch(baseUrl + '/MisAvisos/enviarAviso', {
              method: 'POST',
              body: formData
          })
          .then(response => response.json())
          .then(data => {
              if (data.success) {
                  Swal.fire({
                      type: 'success',
                      title: 'Aviso enviado',
                      text: 'El aviso se ha enviado correctamente.'
                  }).then(() => {
                      window.location.href = baseUrl + '/MisAvisos';
                  });
              } else {
                  Swal.fire({
                      type: 'error',
                      title: 'Error',
                      text: data.message || 'Hubo un problema al enviar el aviso.'
                  });
              }
          })
          .catch(error => {
              Swal.fire({
                  type: 'error',
                  title: 'Error',
                  text: 'Hubo un problema al enviar el aviso.'
              });
              console.error('Error:', error);
          });
      });
  }

  // Editar aviso
  const editAvisoForm = document.getElementById('editAvisoForm');
  if (editAvisoForm) {
      editAvisoForm.addEventListener('submit', function(e) {
          e.preventDefault();

          const formData = new FormData(this);

          fetch(baseUrl + '/MisAvisos/editarAviso', {
              method: 'POST',
              body: formData
          })
          .then(response => response.json())
          .then(data => {
              if (data.success) {
                  Swal.fire({
                      type: 'success',
                      title: 'Aviso actualizado',
                      text: 'El aviso se ha actualizado correctamente.'
                  }).then(() => {
                      $('#editAvisoModal').modal('hide');
                      location.reload();
                  });
              } else {
                  Swal.fire({
                      type: 'error',
                      title: 'Error',
                      text: data.message || 'Hubo un problema al actualizar el aviso.'
                  });
              }
          })
          .catch(error => {
              Swal.fire({
                  type: 'error',
                  title: 'Error',
                  text: 'Hubo un problema al actualizar el aviso.'
              });
              console.error('Error:', error);
          });
      });
  }
});

function openEditModal(avisoId) {
  fetch(baseUrl + '/MisAvisos/obtenerAviso/' + avisoId)
      .then(response => response.json())
      .then(data => {
          document.getElementById('editTitulo').value = data.Titulo;
          document.getElementById('editMensaje').value = data.Mensaje;
          document.getElementById('editFechaInicial').value = data.FechaInicial;
          document.getElementById('editFechaFinal').value = data.FechaFinal;
          document.getElementById('editAvisoId').value = data.PK_Aviso;
          $('#editAvisoModal').modal('show');
      })
      .catch(error => {
          Swal.fire({
              type: 'error',
              title: 'Error',
              text: 'Hubo un problema al obtener el aviso.'
          });
          console.error('Error:', error);
      });
}

function deleteAviso(avisoId) {
  Swal.fire({
      title: '¿Estás seguro?',
      text: "¡No podrás revertir esto!",
      type: 'warning',
      showCancelButton: true,
      confirmButtonColor: '#d33',
      cancelButtonColor: '#3085d6',
      confirmButtonText: 'Sí, eliminarlo!',
      cancelButtonText: 'Cancelar'
  }).then((result) => {
      if (result.value) {
          fetch(baseUrl + '/MisAvisos/deleteAviso/' + avisoId, {
              method: 'POST'
          })
          .then(response => response.json())
          .then(data => {
              if (data.success) {
                  Swal.fire({
                      type: 'success',
                      title: 'Eliminado!',
                      text: 'El aviso ha sido eliminado.'
                  }).then(() => {
                      window.location.reload();
                  });
              } else {
                  Swal.fire({
                      type: 'error',
                      title: 'Error',
                      text: 'Hubo un problema al eliminar el aviso.'
                  });
              }
          })
          .catch(error => {
              Swal.fire({
                  type: 'error',
                  title: 'Error',
                  text: 'Hubo un problema al eliminar el aviso.'
              });
              console.error('Error:', error);
          });
      }
  });
}

$(document).ready(function() {
  $().ready(function() {
      $sidebar = $('.sidebar');

      $sidebar_img_container = $sidebar.find('.sidebar-background');

      $full_page = $('.full-page');

      $sidebar_responsive = $('body > .navbar-collapse');

      window_width = $(window).width();

      fixed_plugin_open = $('.sidebar .sidebar-wrapper .nav li.active a p').html();

      if (window_width > 767 && fixed_plugin_open == 'Dashboard') {
          if ($('.fixed-plugin .dropdown').hasClass('show-dropdown')) {
              $('.fixed-plugin .dropdown').addClass('open');
          }
      }

      $('.fixed-plugin a').click(function(event) {
          if ($(this).hasClass('switch-trigger')) {
              if (event.stopPropagation) {
                  event.stopPropagation();
              } else if (window.event) {
                  window.event.cancelBubble = true;
              }
          }
      });

      $('.fixed-plugin .active-color span').click(function() {
          $full_page_background = $('.full-page-background');

          $(this).siblings().removeClass('active');
          $(this).addClass('active');

          var new_color = $(this).data('color');

          if ($sidebar.length != 0) {
              $sidebar.attr('data-color', new_color);
          }

          if ($full_page.length != 0) {
              $full_page.attr('filter-color', new_color);
          }

          if ($sidebar_responsive.length != 0) {
              $sidebar_responsive.attr('data-color', new_color);
          }
      });

      $('.fixed-plugin .background-color .badge').click(function() {
          $(this).siblings().removeClass('active');
          $(this).addClass('active');

          var new_color = $(this).data('background-color');

          if ($sidebar.length != 0) {
              $sidebar.attr('data-background-color', new_color);
          }
      });

      $('.fixed-plugin .img-holder').click(function() {
          $full_page_background = $('.full-page-background');

          $(this).parent('li').siblings().removeClass('active');
          $(this).parent('li').addClass('active');


          var new_image = $(this).find("img").attr('src');

          if ($sidebar_img_container.length != 0 && $('.switch-sidebar-image input:checked').length != 0) {
              $sidebar_img_container.fadeOut('fast', function() {
                  $sidebar_img_container.css('background-image', 'url("' + new_image + '")');
                  $sidebar_img_container.fadeIn('fast');
              });
          }

          if ($full_page_background.length != 0 && $('.switch-sidebar-image input:checked').length != 0) {
              var new_image_full_page = $('.fixed-plugin li.active .img-holder').find('img').data('src');

              $full_page_background.fadeOut('fast', function() {
                  $full_page_background.css('background-image', 'url("' + new_image_full_page + '")');
                  $full_page_background.fadeIn('fast');
              });
          }

          if ($('.switch-sidebar-image input:checked').length == 0) {
              var new_image = $('.fixed-plugin li.active .img-holder').find("img").attr('src');
              var new_image_full_page = $('.fixed-plugin li.active .img-holder').find('img').data('src');

              $sidebar_img_container.css('background-image', 'url("' + new_image + '")');
              $full_page_background.css('background-image', 'url("' + new_image_full_page + '")');
          }

          if ($sidebar_responsive.length != 0) {
              $sidebar_responsive.css('background-image', 'url("' + new_image + '")');
          }
      });

      $('.switch-sidebar-image input').change(function() {
          $full_page_background = $('.full-page-background');

          $input = $(this);

          if ($input.is(':checked')) {
              if ($sidebar_img_container.length != 0) {
                  $sidebar_img_container.fadeIn('fast');
                  $sidebar.attr('data-image', '#');
              }

              if ($full_page_background.length != 0) {
                  $full_page_background.fadeIn('fast');
                  $full_page.attr('data-image', '#');
              }

              background_image = true;
          } else {
              if ($sidebar_img_container.length != 0) {
                  $sidebar.removeAttr('data-image');
                  $sidebar_img_container.fadeOut('fast');
              }

              if ($full_page_background.length != 0) {
                  $full_page.removeAttr('data-image', '#');
                  $full_page_background.fadeOut('fast');
              }

              background_image = false;
          }
      });

      $('.switch-sidebar-mini input').change(function() {
          $body = $('body');

          $input = $(this);

          if (md.misc.sidebar_mini_active == true) {
              $('body').removeClass('sidebar-mini');
              md.misc.sidebar_mini_active = false;

              $('.sidebar .sidebar-wrapper, .main-panel').perfectScrollbar();

          } else {

              $('.sidebar .sidebar-wrapper, .main-panel').perfectScrollbar('destroy');

              setTimeout(function() {
                  $('body').addClass('sidebar-mini');

                  md.misc.sidebar_mini_active = true;
              }, 300);
          }

          var simulateWindowResize = setInterval(function() {
              window.dispatchEvent(new Event('resize'));
          }, 180);

          setTimeout(function() {
              clearInterval(simulateWindowResize);
          }, 1000);
      });
  });
});
