$('#tareasModal').on('hidden.bs.modal', function () {
  
    $('#tareasContent').empty();

    if ($.fn.DataTable.isDataTable('#tareasTable')) {
        $('#tareasTable').DataTable().clear().destroy();
    }
});

document.getElementById('searchInput').addEventListener('keyup', function() {
    var searchValue = this.value.toLowerCase();
    var table = document.getElementById('alumnosTable');
    var rows = table.getElementsByTagName('tr');

    for (var i = 1; i < rows.length; i++) {
        var cell = rows[i].getElementsByTagName('td')[0]; 
        if (cell) {
            var txtValue = cell.textContent || cell.innerText;
            if (txtValue.toLowerCase().indexOf(searchValue) > -1) {
                rows[i].style.display = '';
            } else {
                rows[i].style.display = 'none';
            }
        }
    }
});

document.addEventListener('DOMContentLoaded', function() {
    var rowsPerPage = 5; 
    var tableBody = document.getElementById('alumnosTableBody');
    var rows = tableBody.getElementsByTagName('tr');
    var pagination = document.getElementById('pagination');
    var totalRows = rows.length;
    var totalPages = Math.ceil(totalRows / rowsPerPage);
    var currentPage = 1;

    function showPage(page) {
        for (var i = 0; i < totalRows; i++) {
            rows[i].style.display = 'none'; 
        }

        var start = (page - 1) * rowsPerPage;
        var end = start + rowsPerPage;
        for (var i = start; i < end && i < totalRows; i++) {
            rows[i].style.display = '';
        }
    }

    function createPagination() {
        pagination.innerHTML = ''; 

        var prevLi = document.createElement('li');
        prevLi.classList.add('page-item');
        var prevLink = document.createElement('a');
        prevLink.classList.add('page-link');
        prevLink.href = '#';
        prevLink.innerHTML = '&laquo;';
        prevLi.appendChild(prevLink);
        pagination.appendChild(prevLi);

        for (var i = 1; i <= totalPages; i++) {
            var li = document.createElement('li');
            li.classList.add('page-item');
            if (i === currentPage) {
                li.classList.add('active');
            }
            var a = document.createElement('a');
            a.classList.add('page-link');
            a.href = '#';
            a.textContent = i;
            a.addEventListener('click', function(e) {
                e.preventDefault();
                currentPage = parseInt(this.textContent);
                showPage(currentPage);
                createPagination();
            });
            li.appendChild(a);
            pagination.appendChild(li);
        }

        var nextLi = document.createElement('li');
        nextLi.classList.add('page-item');
        var nextLink = document.createElement('a');
        nextLink.classList.add('page-link');
        nextLink.href = '#';
        nextLink.innerHTML = '&raquo;';
        nextLi.appendChild(nextLink);
        pagination.appendChild(nextLi);
    }

    showPage(currentPage);
    createPagination();
});

function cargarTareas(userId) {
    $.ajax({
        url: baseUrl + 'alumnos/tareas/' + userId, 
        method: 'GET',
        success: function(response) {
            $('#tareasContent').html(response);

            if ($.fn.DataTable.isDataTable('#tareasTable')) {
                $('#tareasTable').DataTable().clear().destroy();
            }

            $('#tareasTable').DataTable({
                "paging": true,
                "searching": true,
                "ordering": true,
                "info": true,
                "lengthMenu": [5, 10, 15], 
                "pageLength": 5, 
                "language": {
                    "search": "Buscar:",
                    "paginate": {
                        "first": "Primero",
                        "last": "Último",
                        "next": "Siguiente",
                        "previous": "Anterior"
                    },
                    "lengthMenu": "Mostrar _MENU_ registros",
                    "info": "Mostrando _START_ a _END_ de _TOTAL_ registros",
                    "infoEmpty": "No hay registros disponibles",
                    "infoFiltered": "(filtrado de _MAX_ registros en total)"
                }
            });

            $('#tareasModal').modal('show');
        },
        error: function() {
            $('#tareasContent').html('<p>Error al cargar las tareas.</p>');
        }
    });
}
